<?php

/**
 * The file of live filter.
 *
 * @package Postify_pro_for_elementor
 * @subpackage Postify_pro_for_elementor/helper
 *
 * @since 2.0.0
 */

/**
 * Live filter helper method.
 *
 * @since 2.0.0
 */
class POPE_Live_Filter
{
	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    2.0.0
	 */
	public function __construct()
	{
		add_action('wp_ajax_pope_live_filter_reset', array($this, 'pope_live_filter_reset'));
		add_action('wp_ajax_pope_admin_live_filter_reset', array($this, 'pope_admin_live_filter_reset'));
		add_action('wp_ajax_nopriv_pope_live_filter_reset', array($this, 'pope_live_filter_reset'));
	}
	/**
	 * Live filter markup style.
	 *
	 * @param string $btn_type Filter type.
	 * @param string $taxonomy Current taxonomy to view.
	 * @param string $label filter label.
	 * @param string $all_text all text.
	 * @param string $align alignment.
	 * @param bool   $show_count show hide post count.
	 * @param int    $term term id.
	 * @param string $name term name.
	 * @param int    $p_count term found post.
	 * @param int    $id   post id.
	 * @param string $pre_selected selected.
	 * @param string $pre_checked  checked.
	 * @return array
	 */
	public static function pope_filter_style($btn_type, $taxonomy, $label, $all_text, $align = 'center', $show_count = false, $term = null, $name = null, $p_count = null, $id = '', $pre_selected = '', $pre_checked = '')
	{
		if ($show_count) {
			$post_count_markup = '<span class="pope-count">(' . $p_count . ')</span>';
		} else {
			$post_count_markup = '';
		}
		$is_checked       = $pre_checked;
		$is_selected      = $pre_selected;
		$checked          = $pre_checked;
		$selected         = $pre_selected;
		$filter_url_value = isset($_SERVER['QUERY_STRING']) ? wp_unslash($_SERVER['QUERY_STRING']) : '';
		if (!empty($filter_url_value)) {
			$shortcode_id = isset($_GET['sps']) ? wp_unslash(sanitize_text_field($_GET['sps'])) : '';
			if ($shortcode_id == $id) {
				$filter_url_value = isset($_GET["tx_$taxonomy"]) ? wp_unslash(sanitize_text_field($_GET["tx_$taxonomy"])) : '';
				if (!empty($filter_url_value)) {
					if (strpos($filter_url_value, ',') !== false) {
						$filter_url_value = explode(',', $filter_url_value);
					}
					if (is_array($filter_url_value)) {
						if (in_array($term, $filter_url_value)) {
							$is_checked  = 'checked';
							$is_selected = 'selected';
						} else {
							$is_checked  = $pre_checked;
							$is_selected = $pre_selected;
						}
					} else {
						if ($filter_url_value == $term) {
							$is_checked  = 'checked';
							$is_selected = 'selected';
						} else {
							$is_checked  = $pre_checked;
							$is_selected = $pre_selected;
						}
					}
				}
			}
		}

		$checked  = $pre_checked;
		$selected = $pre_selected;

		if ('fl_checkbox' === $btn_type) {
			$all_label  = !empty($all_text) ? $all_text : '';
			$all_button = !empty($all_text) ? '<div class="fl_checkbox"><label><input checked type="checkbox" name="' . $taxonomy . '" data-taxonomy="' . $taxonomy . '"value="all">' . $all_label . '</label></div>' : '';

			$first_item = '<form class="pope-filter-by-checkbox pope-bar" data-taxonomy="' . $taxonomy . '" style="text-align:' . esc_attr($align) . ';"> <p>' . esc_html($label) . '</p>';
			$push_item  = '<div class="fl_checkbox"><label><input ' . $is_checked . ' name="' . $taxonomy . '" type="checkbox" ' . $checked . ' data-taxonomy="' . $taxonomy . '" value="' . $term . '">' . $name . $post_count_markup . '</span></label></div>';
		} elseif ('fl_radio' === $btn_type) {
			$all_label  = !empty($all_text) ? $all_text : '';
			$all_button = !empty($all_text) ? '<div class="fl_radio"><label><input checked type="radio" name="' . $taxonomy . '" data-taxonomy="' . $taxonomy . '"value="all">' . $all_label . '</label></div>' : '';
			$first_item = '<form class="pope-filter-by pope-bar" style="text-align:' . esc_attr($align) . ';"> <p>' . esc_html($label) . '</p>' . $all_button;
			$push_item  = '<div class="fl_radio"><label><input ' . $is_checked . ' name="' . $taxonomy . '" type="radio" ' . $checked . ' data-taxonomy="' . $taxonomy . '" value="' . $term . '">' . $name . $post_count_markup . '</span></label></div>';
		} elseif ('fl_btn' === $btn_type) {
			$all_label  = !empty($all_text) ? '<div>' . $all_text . '</div>' : '';
			$all_button = !empty($all_text) ? '<div class="fl_radio"><label><input checked type="radio" name="' . $taxonomy . '" data-taxonomy="' . $taxonomy . '" value="all">' . $all_label . '</label></div>' : '';

			$first_item = '<form class="pope-filter-by pope-bar fl_button filter-' . $taxonomy . '" style="text-align:' . esc_attr($align) . ';"> <p>' . esc_html($label) . '</p>' . $all_button;
			$push_item  = '<div class="fl_radio"><label><input ' . $is_checked . ' name="' . $taxonomy . '" type="radio" ' . $checked . ' data-taxonomy="' . $taxonomy . '" value="' . $term . '"><div>' . $name . $post_count_markup . '</div></label></div>';
		} else {
			$all_label  = !empty($all_text) ? $all_text : '';
			$all_button = !empty($all_text) ? '<option value="all"  data-taxonomy="' . $taxonomy . '">' . $all_label . '</option>' : '';

			$first_item = '<form class="pope-filter-by pope-bar" style="text-align:' . esc_attr($align) . ';"> <label class="pope-label">' . esc_html($label) . '</label> <select>' . $all_button;
			$push_item  = '<option data-taxonomy="' . $taxonomy . '" ' . $selected . ' ' . $is_selected . ' value="' . $term . '">' . $name . $post_count_markup . '</option>';
		}
		$filter_output = array(
			'first_item' => $first_item,
			'push_item'  => $push_item,
		);
		return $filter_output;
	}
	/**
	 * Multi dimensional to flatten array.
	 *
	 * @param array $array input array.
	 * @return array
	 */
	public static function array_flatten($array)
	{
		if (!is_array($array)) {
			return false;
		}
		$result = array();
		foreach ($array as $key => $value) {
			if (is_array($value)) {
				$result = array_merge($result, self::array_flatten($value));
			} else {
				$result[$key] = $value;
			}
		}
		return $result;
	}
	/**
	 * Term id list after ajax filter.
	 *
	 * @param object $pope_query Post query array.
	 * @param object $taxonomies select Taxonomies.
	 * @return Array
	 */
	public static function pope_all_other_taxonomy_term($pope_query, $taxonomies)
	{
		$post_ids         = $pope_query;
		$y                = 0;
		$final_term_list  = array();
		$taxonomies_count = count($taxonomies);
		while ($y < $taxonomies_count) {
			$term_list = array();
			foreach ($post_ids as $key => $id) {
				$ct_term = wp_get_post_terms($id, $taxonomies[$y], array('fields' => 'ids'));
				if (is_array($ct_term) && !empty($ct_term)) {
					array_push($term_list, $ct_term);
				}
			}
			$term_list                            = array_unique(self::array_flatten($term_list));
			$final_term_list[$taxonomies[$y]] = $term_list;
			$y++;
		}
		return $final_term_list;
	}

	/**
	 * All terms form the query
	 *
	 * @param  array  $pope_query query arg.
	 * @param  string $taxonomy taxonomy.
	 * @return array
	 */
	public static function pope_all_taxonomy_terms_form_the_query($pope_query, $taxonomy)
	{
		$post_ids  = $pope_query;
		$term_list = array();
		foreach ($post_ids as $key => $id) {
			$ct_term = wp_get_post_terms($id, $taxonomy, array('fields' => 'ids'));
			if (is_array($ct_term) && !empty($ct_term)) {
				array_push($term_list, $ct_term);
			}
		}
		return array_unique(self::array_flatten($term_list));
	}
	/**
	 * Live Filter reset after ajax request.
	 */
	public static function pope_live_filter_reset()
	{
		if (isset($_POST['nonce']) && !wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['nonce'])), 'sppope_nonce')) {
			return false;
		}
		$pope_gl_id          = isset($_POST['id']) ? absint($_POST['id']) : '';
		$pope_settings       = isset($_POST['pope_settings']) ? $_POST['pope_settings'] : '';
		$post_per_page       = isset($_POST['post_per_page']) ? $_POST['post_per_page'] : '';
		$pope_post_limit     = isset($_POST['pope_post_limit']) ? $_POST['pope_post_limit'] : '';
		$author_id           = isset($_POST['author_id']) ? sanitize_text_field(wp_unslash($_POST['author_id'])) : '';
		$keyword             = isset($_POST['keyword']) ? sanitize_text_field(wp_unslash($_POST['keyword'])) : '';
		$orderby             = isset($_POST['orderby']) ? sanitize_text_field(wp_unslash($_POST['orderby'])) : '';
		$order               = isset($_POST['order']) ? sanitize_text_field(wp_unslash($_POST['order'])) : '';
		$taxonomy            = isset($_POST['taxonomy']) ? sanitize_text_field(wp_unslash($_POST['taxonomy'])) : '';
		$term_id             = isset($_POST['term_id']) ? sanitize_text_field(wp_unslash($_POST['term_id'])) : '';
		$pope_lang           = isset($_POST['lang']) ? sanitize_text_field(wp_unslash($_POST['lang'])) : '';
		$last_filter         = isset($_POST['last_filter']) ? sanitize_text_field(wp_unslash($_POST['last_filter'])) : '';
		$paged               = isset($_POST['page']) ? sanitize_text_field(wp_unslash($_POST['page'])) : '';
		$custom_fields_array = isset($_POST['custom_fields_array']) ? wp_unslash($_POST['custom_fields_array']) : ''; 
		$selected_term_list  = isset($_POST['term_list']) ? wp_unslash($_POST['term_list']) : ''; 

		$view_options                 = get_post_meta($pope_gl_id, 'ta_pope_view_options', true);
		$query_args                   = POPE_QueryInside::get_filtered_content($view_options, $pope_gl_id, $layout_preset = 'default', $post_per_page, $pope_post_limit, $pope_settings);
		$query_args['fields']         = 'ids';
		$post_limit                   = isset($pope_post_limit) && !empty($pope_post_limit) ? $pope_post_limit : 10000;
		$query_args['posts_per_page'] = $post_limit;
		$query_post_ids               = get_posts($query_args);
		$relation                     = isset($pope_settings['taxonomy_relation']) ? $pope_settings['taxonomy_relation'] : 'AND';
		$is_term_intersect            = true;
		if ('AND' !== $relation) {
			$is_term_intersect = false;
		}
		$query_args = POPE_Functions::modify_query_params($query_args, $keyword, $author_id, $custom_fields_array, $orderby, $order, $selected_term_list, 0, $relation, $query_post_ids, $pope_lang);
		$pope_query  = array();
		self::pope_live_filter($view_options, $pope_settings, $pope_post_limit, $query_args, $pope_gl_id, $is_term_intersect, $selected_term_list, $last_filter);
		self::pope_author_filter($view_options, $pope_settings, $pope_post_limit, $query_args, $author_id);

		wp_die();
	}

	/**
	 * Taxonomy Filter.
	 *
	 * @param array  $view_options options array.
	 * @param  array  $query_args  query array.
	 * @param  string $id shortcode id.
	 * @param  bool   $is_term_intersect is_ajax.
	 * @param  array  $selected_term_list selected term list.
	 * @param  string $last_filter last filter.
	 * @return void
	 */
	public static function pope_live_filter($view_options, $pope_settings, $pope_post_limit, $query_args = '', $id = '', $is_term_intersect = true, $selected_term_list = array(), $last_filter = '')
	{
		$filter_by                    = isset($pope_settings['pope_advanced_filter']) ? $pope_settings['pope_advanced_filter'] : $view_options['pope_advanced_filter'];
		$post_limit                   = isset($pope_post_limit) && !empty($pope_post_limit) ? $pope_post_limit : $view_options['pope_post_limit'];

		$query_args['posts_per_page'] = $post_limit;
		$query_args['fields']         = 'ids';
		if (in_array('taxonomy', $filter_by, true)) {
			$taxonomy_types = isset($pope_settings['taxonomy_options']) && !empty($pope_settings['taxonomy_options']) ? $pope_settings['taxonomy_options'] : $view_options['taxonomy_options'];
			$relation       = isset($pope_settings['taxonomy_relation']) ? $pope_settings['taxonomy_relation'] : $view_options['taxonomy_relation'];
			if (!empty($taxonomy_types)) {
				$output         = '';
				$newterm_array  = array();
				$index          = 0;
				$taxonomies     = array();
				$taxonomy_count = count($taxonomy_types);
				while ($index < $taxonomy_count) {
					$add_filter = isset($taxonomy_types[$index]['add_filter_post']) ? $taxonomy_types[$index]['add_filter_post'] : '';
					
					if ($add_filter) {
						$taxonomy        = isset($taxonomy_types[$index]['select_taxonomy']) ? $taxonomy_types[$index]['select_taxonomy'] : '';
						$all_terms = get_terms($taxonomy);
						$all_term_ids = wp_list_pluck($all_terms, 'term_id');
						$terms           = isset($taxonomy_types[$index]['pope_select_terms']) ? $taxonomy_types[$index]['pope_select_terms'] : $all_term_ids;
						$all_post_ids    = get_posts($query_args);
						$post_limit      = count($all_post_ids);
						$url_last_filter = isset($_GET['slf']) ? wp_unslash(sanitize_text_field($_GET['slf'])) : ''; 

						if (!empty($selected_term_list) && is_array($selected_term_list)) {
							if ($last_filter == $taxonomy && 'AND' === $relation) {
								$new_query = $query_args;
								$tax_query = isset($new_query['tax_query']) ? $new_query['tax_query'] : array();
								if (!empty($tax_query)) {
									foreach ($tax_query as $key => $value) {
										if (is_array($value)) {
											if ($value['taxonomy'] == $taxonomy) {
												unset($tax_query[$key]);
											}
										}
									}
									$new_query['tax_query'] = $tax_query;
									$all_post_ids           = get_posts($new_query);
									$post_limit             = count($all_post_ids);
								}
							}
						} elseif ($url_last_filter == $taxonomy && 'AND' === $relation) {
							$new_query = $query_args;
							$tax_query = isset($new_query['tax_query']) ? $new_query['tax_query'] : array();
							if (!empty($tax_query)) {
								foreach ($tax_query as $key => $value) {
									if (is_array($value)) {
										if ($value['taxonomy'] == $taxonomy) {
											unset($tax_query[$key]);
										}
									}
								}
								$new_query['tax_query'] = $tax_query;
								$all_post_ids           = get_posts($new_query);
								$post_limit             = count($all_post_ids);
							}
						}

						$filter_options = isset($taxonomy_types[$index]['ajax_filter_options']) ? $taxonomy_types[$index]['ajax_filter_options'] : '';
						$all_text       = isset($taxonomy_types[$index]['ajax_rename_all_text']) && !empty($taxonomy_types[$index]['ajax_rename_all_text']) ? $taxonomy_types[$index]['ajax_rename_all_text'] : '';
						if ($is_term_intersect) {
							$new_terms = self::pope_all_taxonomy_terms_form_the_query($all_post_ids, $taxonomy);
							$terms     = is_array($terms) ? $terms : array($terms);
							$terms     = array_intersect($terms, $new_terms);
						}
						
						$btn_style          = isset($taxonomy_types[$index]['ajax_filter_style']) ? $taxonomy_types[$index]['ajax_filter_style'] : 'fl_dropdown';
						$hide_taxonomy_name = isset($taxonomy_types[$index]['hide_taxonomy_name']) ? $taxonomy_types[$index]['hide_taxonomy_name'] : false;
						$show_taxonomy      = !$hide_taxonomy_name ? $taxonomy : '';
						$label              = isset($taxonomy_types[$index]['ajax_filter_label']) && !empty($taxonomy_types[$index]['ajax_filter_label']) ? $taxonomy_types[$index]['ajax_filter_label'] : $show_taxonomy;

						$hide_empty = isset($taxonomy_types[$index]['ajax_hide_empty']) ? $taxonomy_types[$index]['ajax_hide_empty'] : '';
						$show_count = isset($taxonomy_types[$index]['ajax_show_count']) ? $taxonomy_types[$index]['ajax_show_count'] : '';

						$pope_live_filter_align = isset($taxonomy_types[$index]['pope_live_filter_align']) ? $taxonomy_types[$index]['pope_live_filter_align'] : 'center';
						if ($add_filter && !empty($terms) && !empty($taxonomy)) {
							$filter_item             = self::pope_filter_style($btn_style, $taxonomy, $label, $all_text, $pope_live_filter_align);
							$newterm_array[$index] = array($filter_item['first_item']);
							foreach ($terms as $term) {
								$selected = '';
								$checked  = '';
								if (!empty($selected_term_list) && is_array($selected_term_list)) {
									foreach ($selected_term_list as $key => $tax_type) {
										$cr_taxonomy = $tax_type['taxonomy'];
										$cr_terms    = $tax_type['term_id'];
										if (strpos($cr_terms, ',') !== false) {
											$cr_terms = explode(',', $cr_terms);
										} else {
											$cr_terms = array($cr_terms);
										}
										if ($cr_taxonomy == $taxonomy && in_array($term, $cr_terms)) {
											$selected = 'selected';
											$checked  = 'checked';
											break;
										}
									}
								}
								$p_term = get_term($term, $taxonomy);
								if (!is_wp_error($p_term) && !empty($p_term)) {
									$term_post_count = $p_term->count;
									$term_post_count = $term_post_count > $post_limit ? $post_limit : $term_post_count;
									if ($show_count && 'AND' == $relation) {
										$count_query              = $query_args;
										$count_query['tax_query'] = array(
											array(
												'taxonomy' => $taxonomy,
												'field'    => 'term_id',
												'terms'    => $term,
											),
										);
										$count_post_posts         = get_posts($count_query);
										$term_post_count          = count(array_intersect($count_post_posts, $all_post_ids));
									}

									if (!$hide_empty) {
										$push_item = self::pope_filter_style($btn_style, $taxonomy, $label, $all_text, $pope_live_filter_align, $show_count, $term, $p_term->name, $term_post_count, $id, $selected, $checked)['push_item'];
										array_push($newterm_array[$index], $push_item);
									} elseif ($hide_empty && $term_post_count > 0) {
										$push_item = self::pope_filter_style($btn_style, $taxonomy, $label, $all_text, $pope_live_filter_align, $show_count, $term, $p_term->name, $term_post_count, $id, $selected, $checked)['push_item'];
										array_push($newterm_array[$index], $push_item);
									}
								}
							}
							if (!$all_text) {
								$newterm_array[$index][1] = preg_replace('/ type=/i', ' selected checked type=', $newterm_array[$index][1]);
							}
							$tax_html = implode('', $newterm_array[$index]);
							$output   = $output . force_balance_tags($tax_html);
						}
					}
					$index++;
				}
				echo $output; 
			}
		}
	}

	/**
	 * Live Filter reset after ajax request.
	 */
	public static function pope_admin_live_filter_reset()
	{
		if (isset($_POST['nonce']) && !wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['nonce'])), 'sppope_nonce')) {
			return false;
		}
		$pope_gl_id           = isset($_POST['id']) ? absint($_POST['id']) : '';
		$pope_settings       = isset($_POST['pope_settings']) ? $_POST['pope_settings'] : '';
		$post_per_page            = isset($_POST['post_per_page']) ? $_POST['post_per_page'] : '';
		$pope_post_limit            = isset($_POST['pope_post_limit']) ? $_POST['pope_post_limit'] : '';
		$author_id           = isset($_POST['author_id']) ? sanitize_text_field(wp_unslash($_POST['author_id'])) : '';
		$keyword             = isset($_POST['keyword']) ? sanitize_text_field(wp_unslash($_POST['keyword'])) : '';
		$orderby             = isset($_POST['orderby']) ? sanitize_text_field(wp_unslash($_POST['orderby'])) : '';
		$order               = isset($_POST['order']) ? sanitize_text_field(wp_unslash($_POST['order'])) : '';
		$taxonomy            = isset($_POST['taxonomy']) ? sanitize_text_field(wp_unslash($_POST['taxonomy'])) : '';
		$pope_lang            = isset($_POST['lang']) ? sanitize_text_field(wp_unslash($_POST['lang'])) : '';
		$term_id             = isset($_POST['term_id']) ? sanitize_text_field(wp_unslash($_POST['term_id'])) : '';
		$last_filter         = isset($_POST['last_filter']) ? sanitize_text_field(wp_unslash($_POST['last_filter'])) : '';
		$paged               = isset($_POST['page']) ? sanitize_text_field(wp_unslash($_POST['page'])) : '';
		$custom_fields_array = isset($_POST['custom_fields_array']) ? wp_unslash($_POST['custom_fields_array']) : ''; 
		$selected_term_list  = isset($_POST['term_list']) ? wp_unslash($_POST['term_list']) : '';
		$settings            = array(); 
		parse_str($_POST['data'], $settings); 
		$layout                       = $settings['ta_pope_layouts'];
		$layout_preset                = isset($layout['pope_layout_preset']) ? $layout['pope_layout_preset'] : '';
		$view_options                 = $settings['ta_pope_view_options'];
		$query_args                   = POPE_QueryInside::get_filtered_content($view_options, $pope_gl_id, $layout_preset = 'default', $post_per_page, $pope_post_limit, $pope_settings);
		$query_args['fields']         = 'ids';
		$new_query_args               = $query_args;
		$post_limit                   = isset($view_options['pope_post_limit']) && !empty($view_options['pope_post_limit']) ? $view_options['pope_post_limit'] : 10000;
		$query_args['posts_per_page'] = $post_limit;
		$query_post_ids               = get_posts($new_query_args);

		$relation          = isset($pope_settings['taxonomies_relation']) ? $pope_settings['taxonomies_relation'] : 'AND';
		$is_term_intersect = true;
		if ('AND' !== $relation) {
			$is_term_intersect = false;
		}
		$query_args = POPE_Functions::modify_query_params($query_args, $keyword, $author_id, $custom_fields_array, $orderby, $order, $selected_term_list, 0, $relation, $query_post_ids, $pope_lang);
		self::pope_live_filter($view_options, $pope_settings, $pope_post_limit, $query_args, $pope_gl_id, $is_term_intersect, $selected_term_list, $last_filter);
		self::pope_author_filter($view_options, $pope_settings, $pope_post_limit, $query_args, $author_id);
		wp_die();
	}


	/**
	 * Final showing terms list
	 *
	 * @param string $taxonomy taxonomy.
	 * @param string $selected_taxonomy Selected taxonomy.
	 * @param array  $all_term all terms id.
	 * @param array  $terms terms.
	 * @param int    $tax_settings_count taxonomy count.
	 * @param array  $selected_taxs Selected taxonomys.
	 * @param array  $is_other_query_active query.
	 * @return object
	 */
	public static function pope_showing_term($taxonomy, $selected_taxonomy, $all_term, $terms, $tax_settings_count, $selected_taxs, $is_other_query_active = false)
	{
		if ($selected_taxs) {
			if (($selected_taxonomy === $taxonomy && $tax_settings_count < 1) || (count($selected_taxs) <= 1 && $selected_taxs[0] === $taxonomy)) {
				$final_terms = $terms;
			} else {
				$final_terms = array_intersect($all_term, $terms);
			}
		} else {
			if ($is_other_query_active) {
				$final_terms = array_intersect($all_term, $terms);
			} else {
				$final_terms = $terms;
			}
		}

		return $final_terms;
	}

	/**
	 * Author filter bar.
	 *
	 * @param mixed  $view_options options.
	 * @param array  $query_args custom query array.
	 * @param string $current_author current author.
	 * @return void
	 */
	public static function pope_author_filter($view_options, $pope_settings, $pope_post_limit, $query_args, $current_author = '')
	{
		$filter_by            = isset($pope_settings['pope_advanced_filter']) ? $pope_settings['pope_advanced_filter'] : $view_options['pope_advanced_filter'];
		$post_limit           = isset($pope_post_limit) && !empty($pope_post_limit) ? $pope_post_limit : $view_options['pope_post_limit'];
		$pope_select_post_type = 'post';
		if (in_array('author', $filter_by, true)) {
			$add_filter_post       = isset($pope_settings['author_live_filters']) ? $pope_settings['author_live_filters'] : $view_options['author_live_filters'];
			$pope_select_author_by  = isset($pope_settings['select_author']) ? $pope_settings['select_author'] : $view_options['select_author'];
			$btn_type              = isset($pope_settings['author_filter_style']) ? $pope_settings['author_filter_style'] : $view_options['author_filter_style'];
			$author_label                 = isset($view_options['author_filter_label']) && !empty($view_options['author_filter_label']) ? $view_options['author_filter_label'] : 'Author';
			$label                 = isset($pope_settings['author_filter_label']) && !empty($pope_settings['author_filter_label']) ? $pope_settings['author_filter_label'] : $author_label;
			$all_text              = isset($pope_settings['author_rename_all_text']) ? $pope_settings['author_rename_all_text'] : $view_options['author_rename_all_text'];
			$hide_empty            = isset($pope_settings['author_hide_empty']) ? $pope_settings['author_hide_empty'] : $view_options['author_hide_empty'];
			$show_count            = isset($pope_settings['author_show_count']) ? $pope_settings['author_show_count'] : $view_options['author_show_count'];
			$pope_live_filter_align = isset($pope_settings['author_live_filter_align']) ? $pope_settings['author_live_filter_align'] : $view_options['author_live_filter_align'];

			if ($add_filter_post  && is_array($pope_select_author_by)) {
				$filter_item   = self::pope_author_filter_style($btn_type, $label, $all_text, $pope_live_filter_align);
				$newterm_array = array($filter_item['first_item']);
				foreach ($pope_select_author_by as $author_id) {
					$author_name = get_the_author_meta('nicename', $author_id);
					// Prepare the query arguments.
					$query_args['posts_per_page'] = (int) $post_limit;
					$query_args['author__in']     = $author_id;
					$query_args['fields']         = 'ids';
					// Get all the posts.
					if ($current_author === $author_id) {
						$selected = 'selected';
						$checked  = 'checked';
					} else {
						$selected = '';
						$checked  = '';
					}
					$author_posts      = get_posts($query_args);
					$author_post_count = count($author_posts);
					if (!$hide_empty) {
						$push_item = self::pope_author_filter_style($btn_type, $label, $all_text, $pope_live_filter_align, $author_id, $author_name, $author_post_count, $show_count, $selected, $checked)['push_item'];
						array_push($newterm_array, $push_item);
					} elseif ($hide_empty && $author_post_count > 0) {
						$push_item = self::pope_author_filter_style($btn_type, $label, $all_text, $pope_live_filter_align, $author_id, $author_name, $author_post_count, $show_count, $selected, $checked)['push_item'];
						array_push($newterm_array, $push_item);
					}
				}
				$tax_html = implode('', $newterm_array);
				$output   = '';
				$output   = $output . force_balance_tags($tax_html);
				echo $output;
			}
		}
	}

	/**
	 * Orderby filter bar
	 *
	 * @param mixed  $view_options options.
	 * @param array  $query_args custom query.
	 * @param string $sid shortcode id.
	 * @return void
	 */
	public static function pope_orderby_filter_bar($view_options, $pope_settings, $query_args, $sid = null)
	{
		$filter_by = isset($pope_settings['pope_advanced_filter']) ? $pope_settings['pope_advanced_filter'] : $view_options['pope_advanced_filter'];
		if (in_array('sortby', $filter_by, true)) {
			$add_filter_post        = isset($pope_settings['sortby_live_filters']) ? $pope_settings['sortby_live_filters'] : $view_options['sortby_live_filters'];
			$pope_add_filter_orderby = isset($pope_settings['select_sortby']) ? $pope_settings['select_sortby'] : $view_options['select_sortby'];
			$btn_type               = isset($pope_settings['sortby_filter_style']) ? $pope_settings['sortby_filter_style'] : $view_options['sortby_filter_style'];
			$label                  = isset($pope_settings['sortby_filter_label']) && !empty($pope_settings['sortby_filter_label']) ? $pope_settings['sortby_filter_label'] : $view_options['sortby_filter_label'];
			$pope_live_filter_align  = isset($pope_settings['sortby_live_filter_align']) ? $pope_settings['sortby_live_filter_align'] :  $view_options['sortby_live_filter_align'];

			if ($add_filter_post && is_array($pope_add_filter_orderby)) {
				$filter_item   = self::pope_orderby_filter_style($btn_type, $label, $pope_live_filter_align);
				$newterm_array = array($filter_item['first_item']);
				foreach ($pope_add_filter_orderby as $orderby) {
					$push_item = self::pope_orderby_filter_style($btn_type, $label, $pope_live_filter_align, $orderby, $sid)['push_item'];
					array_push($newterm_array, $push_item);
				}
				$tax_html = implode('', $newterm_array);
				$output   = '';
				$output   = $output . force_balance_tags($tax_html);
				echo $output; 
			}
		}
	}

	/**
	 * Order filter button.
	 *
	 * @param mixed  $view_options options.
	 * @param string $sid shortcode id.
	 * @return void
	 */
	public static function pope_order_filter_bar($view_options, $pope_settings, $sid = null)
	{
		$filter_by = isset($pope_settings['pope_advanced_filter']) ? $pope_settings['pope_advanced_filter'] : $view_options['pope_advanced_filter'];
		if (in_array('sortby', $filter_by)) {
			$add_filter_post         	= isset($pope_settings['add_order_filter_post']) ? $pope_settings['add_order_filter_post'] : $view_options['add_order_filter_post'];
			$select_filter_order 		= isset($pope_settings['select_filter_order']) ? $pope_settings['select_filter_order'] : $view_options['select_filter_order'];
			$pope_add_filter_orderby  	= array('DESC', 'ASC');
			$btn_type                	= isset($pope_settings['order_filter_options']) ? $pope_settings['order_filter_options'] : $view_options['order_filter_options'];
			$label                   	= isset($pope_settings['order_filter_label']) ? $pope_settings['order_filter_label'] : $view_options['order_filter_label'];
			$pope_live_filter_align   	= isset($pope_settings['pope_live_filter_align']) ? $pope_settings['pope_live_filter_align'] : $view_options['pope_live_filter_align'];
			if ($add_filter_post) {
				$filter_item   	= self::pope_order_filter_style($btn_type, $label, $pope_live_filter_align);
				$newterm_array 	= array($filter_item['first_item']);
				foreach ($pope_add_filter_orderby as $order) {
					$push_item 	= self::pope_order_filter_style($btn_type, $label, $pope_live_filter_align, $order, $select_filter_order, $sid)['push_item'];
					array_push($newterm_array, $push_item);
				}
				$tax_html 		= implode('', $newterm_array);
				$output   		= '';
				$output   		= $output . force_balance_tags($tax_html);
				echo $output;
			}
		}
	}

	/**
	 * Author filter type.
	 *
	 * @param string  $btn_type button type.
	 * @param string  $label author filter label.
	 * @param string  $all_text all text.
	 * @param int     $align alignment.
	 * @param int     $author_id author id.
	 * @param string  $author_name user name.
	 * @param int     $author_post_count  user post count.
	 * @param boolean $show_count show/hide post count.
	 * @param string  $selected select.
	 * @param string  $checked check.
	 */
	public static function pope_author_filter_style($btn_type, $label, $all_text, $align = 'center', $author_id = null, $author_name = null, $author_post_count = null, $show_count = true, $selected = '', $checked = '')
	{
		if ($show_count) {
			$post_count_markup = '<span class="pope-count">(' . $author_post_count . ')</span>';
		} else {
			$post_count_markup = '';
		}

		$final_author_url_value = isset($_GET['pope_author_id']) ? wp_unslash(sanitize_text_field($_GET['pope_author_id'])) : '';
		if ($final_author_url_value == $author_id) {
			$a_selected = 'selected';
			$a_checked  = 'checked';
		} else {
			$a_selected = $selected;
			$a_checked  = $checked;
		}
		if ('fl_radio' === $btn_type) {
			$all_label  = !empty($all_text) ? $all_text : '';
			$first_item = '<div class="pope-author-filter pope-bar" style="text-align:' . esc_attr($align) . ';"><p>' . esc_html($label) . '</p><div class="fl_radio"><label><input checked type="radio" name="author" value="all">' . $all_label . '</label></div>';
			$push_item  = '<div class="fl_radio"><label><input name="author" type="radio" ' . $a_checked . ' value="' . esc_attr($author_id) . '">' . esc_attr($author_name) . $post_count_markup . '</label></div>';
		} elseif ('fl_btn' === $btn_type) {
			$all_label  = !empty($all_text) ? '<div>' . $all_text . '</div>' : '';
			$first_item = '<div class="pope-author-filter pope-bar fl_button" style="text-align:' . esc_attr($align) . ';"> <p>' . esc_html($label) . '</p><div class="fl_radio"><label><input checked type="radio" name="author" value="all">' . $all_label . '</label></div>';
			$push_item  = '<div class="fl_radio"><label><input name="author" type="radio" ' . $a_checked . ' value="' . esc_attr($author_id) . '"><div>' . esc_attr($author_name) . $post_count_markup . '</div></label></div>';
		} else {
			$all_label  = !empty($all_text) ? $all_text : '';
			$first_item = '<div class="pope-author-filter pope-bar" style="text-align:' . esc_attr($align) . ';"> <label class="pope-label">' . esc_html($label) . '</label><select><option  name="author" value="all">' . $all_label . '</option>';
			$push_item  = '<option name="author" value="' . esc_attr($author_id) . '" ' . $a_selected . '>' . esc_attr($author_name) . $post_count_markup . ' </option>';
		}
		$filter_output = array(
			'first_item' => $first_item,
			'push_item'  => $push_item,
		);
		return $filter_output;
	}

	/**
	 * Custom field filter style
	 *
	 * @param  string $btn_type btn_type.
	 * @param  string $label label.
	 * @param  string $all_text all text.
	 * @param  string $align alignment.
	 * @param  string $field_key key.
	 * @param  string $value  field value.
	 * @param  string $p_count post count.
	 * @param  string $id shortcode id.
	 * @param  string $selected selected text.
	 * @param  string $checked checked.
	 * @param  bool   $show_count is show post count.
	 * @return statement
	 */
	public static function pope_custom_field_filter_style($btn_type, $label = 'Custom field', $all_text = 'All', $align = 'center', $field_key = null, $value = null, $p_count = '', $id = '', $selected = '', $checked = '', $show_count = false)
	{
		$post_count_markup = '';
		if ($show_count) {
			$post_count_markup = '<span class="pope-count">(' . $p_count . ')</span>';
		}
		$a_selected       = $selected;
		$a_checked        = $checked;
		$capitalize_value = ucfirst(apply_filters('ta_pope_custom_meta_filter_value', $value, $field_key)) . $post_count_markup;

		$filter_url_value = isset($_SERVER['QUERY_STRING']) ? wp_unslash($_SERVER['QUERY_STRING']) : '';
		if (!empty($filter_url_value)) {
			$shortcode_id = isset($_GET['sps']) ? wp_unslash(sanitize_text_field($_GET['sps'])) : '';
			if ($shortcode_id == $id) {
				$filter_value = isset($_GET["cf$field_key"]) ? wp_unslash(sanitize_text_field($_GET["cf$field_key"])) : '';
				if (!empty($filter_value)) {
					if (strpos($filter_value, ',') !== false) {
						$filter_value = explode(',', $filter_value);
					}

					if (is_array($filter_value)) {
						if (in_array($value, $filter_value)) {
							$a_checked  = 'checked';
							$a_selected = 'selected';
						} else {
							$is_checked  = $checked;
							$is_selected = $selected;
						}
					} else {
						if ($filter_value == $value) {
							$a_checked  = 'checked';
							$a_selected = 'selected';
						} else {
							$a_checked  = $checked;
							$a_selected = $selected;
						}
					}
				}
			}
		}

		if ('fl_checkbox' === $btn_type) {
			$first_item = '<div class="pope-custom-field-filter-checkbox pope-bar" style="text-align:' . esc_attr($align) . ';"><p>' . esc_html($label) . '</p>';
			$push_item  = '<div class="fl_checkbox"><label><input name="' . esc_attr($field_key) . '" type="checkbox" ' . $a_checked . '  value="' . esc_attr($value) . '">' . wp_kses_post($capitalize_value) . '</span></label></div>';
		} elseif ('fl_radio' === $btn_type) {
			$all_label  = !empty($all_text) ? $all_text : '';
			$first_item = '<div class="pope-custom-field-filter pope-bar" style="text-align:' . esc_attr($align) . ';"><p>' . esc_html($label) . '</p><div class="fl_radio"><label><input checked type="radio" name="' . esc_attr($field_key) . '" value="all">' . $all_label . '</label></div>';
			$push_item  = '<div class="fl_radio"><label><input name="' . esc_attr($field_key) . '" type="radio" ' . $a_checked . ' value="' . esc_attr($value) . '">' . wp_kses_post($capitalize_value) . '</label></div>';
		} elseif ('fl_btn' === $btn_type) {
			$all_label  = !empty($all_text) ? '<div>' . esc_html($all_text) . '</div>' : '';
			$first_item = '<div class="pope-custom-field-filter pope-bar fl_button filter-' . $field_key . '" style="text-align:' . esc_attr($align) . ';"> <p>' . esc_html($label) . '</p><div class="fl_radio"><label><input checked type="radio" name="' . esc_attr($field_key) . '" value="all">' . $all_label . '</label></div>';
			$push_item  = '<div class="fl_radio"><label><input name="' . esc_attr($field_key) . '" type="radio" ' . $a_checked . ' value="' . esc_attr($value) . '"><div>' . wp_kses_post($capitalize_value) . '</div></label></div>';
		} else {
			$all_label  = !empty($all_text) ? $all_text : '';
			$first_item = '<div class="pope-custom-field-filter pope-bar" style="text-align:' . esc_attr($align) . ';"> <label class="pope-label">' . esc_html($label) . '</label><select><option  name="' . $field_key . '" value="all">' . $all_label . '</option>';
			$push_item  = '<option name="' . $field_key . '" value="' . $value . '" ' . $a_selected . '>' . wp_kses_post($capitalize_value) . ' </option>';
		}
		$filter_output = array(
			'first_item' => $first_item,
			'push_item'  => $push_item,
		);
		return $filter_output;
	}
	/**
	 * Order by filter bar style.
	 *
	 * @param string $btn_type button type.
	 * @param string $label order by label.
	 * @param string $align alignment.
	 * @param string $orderby order text.
	 * @param string $sid shortcode id.
	 * @return array
	 */
	public static function pope_orderby_filter_style($btn_type, $label, $align = 'center', $orderby = null, $sid = null)
	{
		$filter_url_value        = isset($_SERVER['QUERY_STRING']) ? wp_unslash($_SERVER['QUERY_STRING']) : '';
		$final_orderby_url_value = '';
		if (!empty($filter_url_value)) {
			$shortcode_id = isset($_GET['sps']) ? wp_unslash(sanitize_text_field($_GET['sps'])) : '';
			if ($shortcode_id == $sid) {
				$final_orderby_url_value = isset($_GET['pope_orderby']) ? sanitize_text_field(wp_unslash($_GET['pope_orderby'])) : '';
			}
		}

		if ($final_orderby_url_value == $orderby) {
			$is_selected = 'selected';
			$is_checked  = 'checked';
		} else {
			$is_selected = '';
			$is_checked  = '';
		}

		if ('fl_radio' === $btn_type) {
			$first_item = '<div class="pope-order-by pope-bar" style="text-align:' . esc_attr($align) . ';"><p>' . esc_html($label) . '</p><div class="fl_radio"><label><input checked type="radio" name="orderby" value="">None</label></div>';
			$push_item  = '<div class="fl_radio"><label><input name="orderby" type="radio"  ' . $is_checked . ' value="' . $orderby . '">' . $orderby . '</label></div>';
		} elseif ('fl_btn' === $btn_type) {
			$first_item = '<div class="pope-order-by pope-bar fl-btn" style="text-align:' . esc_attr($align) . ';"><p>' . esc_html($label) . '</p> <div class="fl_radio"><label><input checked type="radio" name="orderby" value=""><div>None</div></label></div>';
			$push_item  = '<div class="fl_radio"><label><input type="radio" name="orderby" ' . $is_checked . ' value="' . $orderby . '"><div>' . $orderby . '</div></label></div>';
		} else {
			$first_item = '<div class="pope-order-by pope-bar" style="text-align:' . esc_attr($align) . ';"><p>' . esc_html($label) . '</p><select><option  name="orderby" value="">None</option>';
			$push_item  = '<option name="orderby" ' . $is_selected . ' value="' . $orderby . '">' . $orderby . '</option>';
		}
		$filter_output = array(
			'first_item' => $first_item,
			'push_item'  => $push_item,
		);
		return $filter_output;
	}

	/**
	 * Order filter style
	 *
	 * @param string $btn_type button type.
	 * @param string $label order filter label.
	 * @param string $align alignment text.
	 * @param string $order order text.
	 * @param string $select_order selected order.
	 * @param string $sid shortcode id.
	 */
	public static function pope_order_filter_style($btn_type, $label, $align = 'center', $order = null, $select_order = null, $sid = null)
	{
		$final_order_url_value = '';
		$filter_url_value      = isset($_SERVER['QUERY_STRING']) ? wp_unslash($_SERVER['QUERY_STRING']) : '';
		if (!empty($filter_url_value)) {
			$shortcode_id = isset($_GET['sps']) ? wp_unslash(sanitize_text_field($_GET['sps'])) : '';
			if ($shortcode_id == $sid) {
				$final_order_url_value = isset($_GET['pope_order']) ? sanitize_text_field(wp_unslash($_GET['pope_order'])) : '';
			}
		}

		if ($final_order_url_value == $order) {
			$checked  = 'checked';
			$selected = 'selected';
		} else {
			$selected = '';
			$checked  = '';
		}
		if ('fl_radio' === $btn_type) {
			$first_item = '<div class="pope-order pope-bar" style="text-align:' . esc_attr($align) . ';"><p>' . esc_html($label) . '</p>';
			$push_item  = '<div class="fl_radio"><label><input name="order" ' . $checked . ' type="radio" value="' . $order . '">' . $order . '</label></div>';
		} elseif ('fl_btn' === $btn_type) {
			$first_item = '<div class="pope-order pope-bar fl-btn" style="text-align:' . esc_attr($align) . ';"><p>' . esc_html($label) . '</p>';
			$push_item  = '<div class="fl_radio"><label><input type="radio" ' . $checked . ' name="order" value="' . $order . '"><div>' . $order . '</div></label></div>';
		} else {
			$first_item = '<div class="pope-order pope-bar" style="text-align:' . esc_attr($align) . ';"><p>' . esc_html($label) . '</p><select>';
			$push_item  = '<option name="order" ' . $selected . ' value="' . $order . '">' . $order . '</option>';
		}
		$filter_output = array(
			'first_item' => $first_item,
			'push_item'  => $push_item,
		);
		return $filter_output;
	}

	/**
	 * Live search bar
	 *
	 * @param int    $view_options options.
	 * @param string $sid shortcode id.
	 * @return void
	 */
	public static function pope_live_search_bar($view_options, $pope_settings, $sid = null)
	{
		$filter_by        = isset($pope_settings['pope_advanced_filter']) ? $pope_settings['pope_advanced_filter'] : $view_options['pope_advanced_filter'];
		$final_keyword    = '';
		$filter_url_value = isset($_SERVER['QUERY_STRING']) ? wp_unslash($_SERVER['QUERY_STRING']) : '';
		if (!empty($filter_url_value)) {
			$shortcode_id = isset($_GET['sps']) ? wp_unslash(sanitize_text_field($_GET['sps'])) : '';
			if ($shortcode_id == $sid) {
				$final_keyword = isset($_GET['pope_keyword']) ? sanitize_text_field(wp_unslash($_GET['pope_keyword'])) : '';
			}
		}
		if (in_array('keyword', $filter_by, true)) {
			$add_filter_post       = isset($pope_settings['add_search_filter_post']) ? $pope_settings['add_search_filter_post'] : $view_options['add_search_filter_post'];
			if ($add_filter_post) {
				$label                 = isset($pope_settings['keyword_filter_label']) && !empty($pope_settings['keyword_filter_label']) ? $pope_settings['keyword_filter_label'] : $view_options['keyword_filter_label'];
				$pope_live_filter_align = isset($pope_settings['keyword_live_filter_align']) ? $pope_settings['keyword_live_filter_align'] : $view_options['keyword_live_filter_align'];
				echo '<div class="pope-ajax-search pope-bar" style="text-align:' . esc_attr($pope_live_filter_align) . ';"><label class="pope-label">' . wp_kses_post($label) . ' <input type="text" value="' . esc_attr($final_keyword) . '" class="pope-search-field" placeholder="Search..."></label></div>';
			}
		}
	}
}
