<?php

/*
 * Plugin Name:       Postify Pro For Elementor
 * Plugin URI:        http://wp-plugins.themeatelier.net/postify
 * Description:       Post layouts for Eelementor
 * Version:           1.0.1
 * Requires at least: 5.2
 * Requires PHP:      7.2
 * Author:            ThemeAtelier
 * Author URI:        https://themeatelier.net/
 * License:           GPL v2 or later
 * License URI:       https://www.gnu.org/licenses/gpl-2.0.html
 * Update URI:        https://example.com/my-plugin/
 * Text Domain:       postify-pro-for-elementor
 * Domain Path:       /languages
 * Elementor tested up to: 3.16.0
 * Elementor Pro tested up to: 3.16.0
 */

if (!defined('ABSPATH')) exit();

/**
 * Elementor Extension main CLass
 * @since 1.0.0
 */
final class Postify_Pro_For_Elementor
{

    /**
	 * Script and style suffix
	 *
	 * @since 2.2.0
	 * @access protected
	 * @var string
	 */
	protected $suffix;

    // Minimum Elementor Version
    const MINIMUM_ELEMENTOR_VERSION = '3.5.0';

    // Minimum PHP Version
    const MINIMUM_PHP_VERSION = '7.3';

    // Instance
    private static $_instance = null;

    /**
     * SIngletone Instance Method
     * @since 1.0.0
     */
    public static function instance()
    {
        if (is_null(self::$_instance)) {
            self::$_instance = new self();
        }
        return self::$_instance;
    }

    /**
     * Construct Method
     * @since 1.0.0
     */
    public function __construct()
    {
        // Call Constants Method
        $this->define_constants();
        add_action('wp_enqueue_scripts', [$this, 'scripts_styles']);
        add_action('init', [$this, 'i18n']);
        add_action('plugins_loaded', [$this, 'init']);
    }

    /**
     * Define Plugin Constants
     * @since 1.0.0
     */
    public function define_constants()
    {
        define('PPFE_PLUGIN_VERSION', '1.0.1');
        define('PPFE_PLUGIN_URL', trailingslashit(plugins_url('/', __FILE__)));
        define('PPFE_PLUGIN_PATH', trailingslashit(plugin_dir_path(__FILE__)));
    }

    /**
     * Load Scripts & Styles
     * @since 1.0.0
     */
    public function scripts_styles()
    {
        wp_register_script('swiper-bundle', PPFE_PLUGIN_URL . 'assets/dist/js/swiper-bundle.min.js', array('jquery'), PPFE_PLUGIN_VERSION, true);
        wp_register_script('bx-slider', PPFE_PLUGIN_URL . 'assets/dist/js/jquery.bxslider.min.js', array('jquery'), PPFE_PLUGIN_VERSION, true);
        wp_register_script('pope-lazyload', PPFE_PLUGIN_URL . 'assets/dist/js/pope-lazyload.js', array('swiper-bundle', 'bx-slider', 'jquery'), PPFE_PLUGIN_VERSION, true);
        wp_register_script('grid_scripts', PPFE_PLUGIN_URL . 'assets/dist/js/grid-scripts.js', array('swiper-bundle', 'bx-slider', 'jquery'), PPFE_PLUGIN_VERSION, true);
        wp_register_script('carousel_scripts', PPFE_PLUGIN_URL . 'assets/dist/js/carousel-scripts.js', array('swiper-bundle', 'bx-slider', 'jquery'), PPFE_PLUGIN_VERSION, true);

        wp_register_style('fontawesome', PPFE_PLUGIN_URL . 'assets/dist/css/fontawesome.min.css');
        wp_register_style('bx-slider', PPFE_PLUGIN_URL . 'assets/dist/css/jquery.bxslider.min.css');
        wp_register_style('swiper-bundle', PPFE_PLUGIN_URL . 'assets/dist/css/swiper-bundle.min.css');
        wp_register_style('postify-main', PPFE_PLUGIN_URL . 'assets/dist/css/postify.main.min.css', [], PPFE_PLUGIN_VERSION, 'all');
		\Elementor\Plugin::instance()->frontend->register_styles();
        wp_localize_script(
            'grid_scripts',
            'sppop',
            array(
                'ajaxurl' => admin_url('admin-ajax.php'),
                'nonce'   => wp_create_nonce('sppope_nonce'),
            )
        );
        wp_localize_script(
            'carousel_scripts',
            'sppop',
            array(
                'ajaxurl' => admin_url('admin-ajax.php'),
                'nonce'   => wp_create_nonce('sppope_nonce'),
            )
        );
    }

    /**
     * Load Text Domain
     * @since 1.0.0
     */
    public function i18n()
    {
        load_plugin_textdomain('postify-pro-for-elementor', false, dirname(plugin_basename(__FILE__)) . '/languages');
    }

    /**
     * Initialize the plugin
     * @since 1.0.0
     */
    public function init()
    {
        // Check if the ELementor installed and activated
        if (!did_action('elementor/loaded')) {
            add_action('admin_notices', [$this, 'admin_notice_missing_main_plugin']);
            return;
        }

        if (!version_compare(ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=')) {
            add_action('admin_notices', [$this, 'admin_notice_minimum_elementor_version']);
            return;
        }

        if (!version_compare(PHP_VERSION, self::MINIMUM_PHP_VERSION, '>=')) {
            add_action('admin_notices', [$this, 'admin_notice_minimum_php_version']);
            return;
        }

        add_action('elementor/init', [$this, 'init_category']);
        add_action('elementor/widgets/widgets_registered', [$this, 'init_widgets']);

        require_once PPFE_PLUGIN_PATH . 'helpers/class-postify-pro-image-resizer.php';
        require_once PPFE_PLUGIN_PATH . 'helpers/class-pope-user-like.php';
		new POPE_User_Like();
        require_once PPFE_PLUGIN_PATH . 'helpers/class-post-functions.php';
        require_once PPFE_PLUGIN_PATH . 'helpers/class-pope-queryinside.php';
        require_once PPFE_PLUGIN_PATH . 'helpers/class-pope-live-filter.php';
		new POPE_Live_Filter();
        require_once PPFE_PLUGIN_PATH . 'helpers/class-loop-html.php';


        add_action('wp_ajax_post_grid_ajax', array($this, 'post_grid_ajax'));
        add_action('wp_ajax_nopriv_post_grid_ajax', array($this, 'post_grid_ajax'));

        add_action('wp_ajax_post_pagination_bar', array($this, 'post_pagination_bar'));
        add_action('wp_ajax_nopriv_post_pagination_bar', array($this, 'post_pagination_bar'));

        add_action('wp_ajax_post_pagination_bar_mobile', array($this, 'post_pagination_bar_mobile'));
        add_action('wp_ajax_nopriv_post_pagination_bar_mobile', array($this, 'post_pagination_bar_mobile'));

        add_action('wp_ajax_pope_post_order', array($this, 'pope_post_order'));
        add_action('wp_ajax_nopriv_pope_post_order', array($this, 'pope_post_order'));

    }

    /**
	 * Post Ajax Pagination.
	 */
	public function post_grid_ajax()
	{
        if (isset($_POST['nonce']) && !wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['nonce'])), 'sppope_nonce')) {
            return false;
		}
		$views_id            = isset($_POST['id']) ? $_POST['id'] : '';
		$pope_settings       = isset($_POST['pope_settings']) ? $_POST['pope_settings'] : '';
		$pagination_type     = isset($_POST['pagination_type']) ? $_POST['pagination_type'] : '';
		$post_per_page       = isset($_POST['post_per_page']) ? $_POST['post_per_page'] : '';
		$pope_post_limit     = isset($_POST['pope_post_limit']) ? $_POST['pope_post_limit'] : '';
		$author_id           = isset($_POST['author_id']) ? sanitize_text_field(wp_unslash($_POST['author_id'])) : '';
		$keyword             = isset($_POST['keyword']) ? sanitize_text_field(wp_unslash($_POST['keyword'])) : '';
		$orderby             = isset($_POST['orderby']) ? sanitize_text_field(wp_unslash($_POST['orderby'])) : '';
		$order               = isset($_POST['order']) ? sanitize_text_field(wp_unslash($_POST['order'])) : '';
		$taxonomy            = isset($_POST['taxonomy']) ? sanitize_text_field(wp_unslash($_POST['taxonomy'])) : '';
		$term_id             = isset($_POST['term_id']) ? sanitize_text_field(wp_unslash($_POST['term_id'])) : '';
		$pope_lang           = isset($_POST['lang']) ? sanitize_text_field(wp_unslash($_POST['lang'])) : '';
		$paged               = isset($_POST['page']) ? sanitize_text_field(wp_unslash($_POST['page'])) : '';
		$custom_fields_array = isset($_POST['custom_fields_array']) ? wp_unslash($_POST['custom_fields_array']) : '';
		$selected_term_list  = isset($_POST['term_list']) ? wp_unslash($_POST['term_list']) : '';
		$layout_preset 		= $pope_settings['layout_preset'];
		$view_options  		= get_post_meta($views_id, 'ta_pope_view_options', true);
		// Post display settings.
		if ('ajax_number' === $pagination_type) {
            if (empty($paged)) {
                $paged = isset($_POST['page']) ? sanitize_text_field(wp_unslash($_POST['page'])) : '';
			}
		}
		$post_content_sorter              = isset($view_options['post_content_sorter']) ? $view_options['post_content_sorter'] : '';
		$query_args                       = POPE_QueryInside::get_filtered_content($view_options, $views_id, $layout_preset, $post_per_page, $pope_post_limit, $pope_settings);
		$post_limit                       = isset($pope_post_limit) && !empty($pope_post_limit) ? $pope_post_limit : 10000;
		$post_offset                      = isset($view_options['pope_post_offset']) ? $view_options['pope_post_offset'] : 0;
		$new_query_args                   = $query_args;
		$new_query_args['fields']         = 'ids';
		$new_query_args['posts_per_page'] = $post_limit;
		$query_post_ids                   = get_posts($new_query_args);
		$relation                         = isset($pope_settings['taxonomies_relation']) ? $pope_settings['taxonomies_relation'] : 'AND';
		$query_args                       = POPE_Functions::modify_query_params($query_args, $keyword, $author_id, $custom_fields_array, $orderby, $order, $selected_term_list, $post_offset, $relation, $query_post_ids, $pope_lang);
		$new_query_args                   = $query_args;
		$new_query_args['fields']         = 'ids';
		$new_query_args['posts_per_page'] = $post_limit;
		$total_posts                      = count(get_posts($new_query_args));
		$post_limit                       = $total_posts;
        
		if ($post_limit > 0) {
			$post_per_page = ($post_per_page > $post_limit) ? $post_limit : $post_per_page;
			if ($post_limit < 1) {
				$total_page = 0;
			} else {
				$total_page = POPE_Functions::pope_max_pages($post_limit, $post_per_page);
			}
			$pope_last_page_post   = POPE_Functions::pope_last_page_post($post_limit, $post_per_page, $total_page);
			$offset               = (int) $post_per_page * ($paged - 1);
			$query_args['offset'] = (int) $offset + (int) $post_offset;
			if ($total_page == $paged) {
				$query_args['posts_per_page'] = $pope_last_page_post;
			}
			if ($paged > $total_page) {
				return false;
			}
		}
		$query_args['paged'] = $paged;
		$pope_query           = new WP_Query($query_args);
		POPE_HTML::pope_get_posts($view_options, $layout_preset, $post_content_sorter, $pope_query, $views_id, $pope_settings);
		die();
	}

	/**
	 * Post Ajax Pagination.
	 */
	public static function post_pagination_bar()
	{
		if (isset($_POST['nonce']) && !wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['nonce'])), 'sppope_nonce')) {
			return false;
		}
		$views_id            = isset($_POST['id']) ? absint($_POST['id']) : '';
		$pope_settings       = isset($_POST['pope_settings']) ? $_POST['pope_settings'] : '';
		$post_per_page            = isset($_POST['post_per_page']) ? $_POST['post_per_page'] : '';
		$pope_post_limit            = isset($_POST['pope_post_limit']) ? $_POST['pope_post_limit'] : '';

		$author_id           = isset($_POST['author_id']) ? sanitize_text_field(wp_unslash($_POST['author_id'])) : '';
		$keyword             = isset($_POST['keyword']) ? sanitize_text_field(wp_unslash($_POST['keyword'])) : '';
		$orderby             = isset($_POST['orderby']) ? sanitize_text_field(wp_unslash($_POST['orderby'])) : '';
		$order               = isset($_POST['order']) ? sanitize_text_field(wp_unslash($_POST['order'])) : '';
		$taxonomy            = isset($_POST['taxonomy']) ? sanitize_text_field(wp_unslash($_POST['taxonomy'])) : '';
		$term_id             = isset($_POST['term_id']) ? sanitize_text_field(wp_unslash($_POST['term_id'])) : '';
		$pope_lang            = isset($_POST['lang']) ? sanitize_text_field(wp_unslash($_POST['lang'])) : '';
		$paged               = isset($_POST['page']) ? sanitize_text_field(wp_unslash($_POST['page'])) : '';
		$custom_fields_array = isset($_POST['custom_fields_array']) ? wp_unslash($_POST['custom_fields_array']) : '';
		$selected_term_list  = isset($_POST['term_list']) ? wp_unslash($_POST['term_list']) : '';
		$view_options        = get_post_meta($views_id, 'ta_pope_view_options', true);
		$layout_preset       = $pope_settings['layout_preset'];
		$pagination_type     = isset($pope_settings['post_pagination_type']) ? $pope_settings['post_pagination_type'] : '';
		$pagination_type     = isset($view_options['post_pagination_type_mobile']) ? $view_options['post_pagination_type_mobile'] : '';
		$query_args          = POPE_QueryInside::get_filtered_content($view_options, $views_id, $layout_preset, $post_per_page, $pope_post_limit, $pope_settings);

		$post_offset                      = isset($pope_settings['pope_post_offset']) ? $pope_settings['pope_post_offset'] : 0;
		$new_query_args                   = $query_args;
		$new_query_args['fields']         = 'ids';
		$post_limit                       = isset($pope_settings['pope_post_limit']) && !empty($pope_settings['pope_post_limit']) ? $pope_settings['pope_post_limit'] : 10000;
		$new_query_args['posts_per_page'] = $post_limit;
		$query_post_ids                   = get_posts($new_query_args);

		$relation           = isset($pope_settings['taxonomies_relation']) ? $pope_settings['taxonomies_relation'] : 'AND';
		$query_args         = POPE_Functions::modify_query_params($query_args, $keyword, $author_id, $custom_fields_array, $orderby, $order, $selected_term_list, $post_offset, $relation, $query_post_ids, $pope_lang);
		$query_args['lang'] = '';
		$pope_query          = new WP_Query($query_args);

		POPE_HTML::pope_pagination_bar($pope_query, $view_options, $layout_preset, $views_id, $pope_settings, $post_per_page, $pope_post_limit);
		die();
	}

	/**
	 * Post Ajax mobile Pagination.
	 */
	public static function post_pagination_bar_mobile()
	{
		if (isset($_POST['nonce']) && !wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['nonce'])), 'sppope_nonce')) {
			return false;
		}
		$views_id            = isset($_POST['id']) ? absint($_POST['id']) : '';
		$pope_settings       = isset($_POST['pope_settings']) ? $_POST['pope_settings'] : '';
		$post_per_page            = isset($_POST['post_per_page']) ? $_POST['post_per_page'] : '';
		$pope_post_limit            = isset($_POST['pope_post_limit']) ? $_POST['pope_post_limit'] : '';
		$author_id           = isset($_POST['author_id']) ? sanitize_text_field(wp_unslash($_POST['author_id'])) : '';
		$keyword             = isset($_POST['keyword']) ? sanitize_text_field(wp_unslash($_POST['keyword'])) : '';
		$orderby             = isset($_POST['orderby']) ? sanitize_text_field(wp_unslash($_POST['orderby'])) : '';
		$order               = isset($_POST['order']) ? sanitize_text_field(wp_unslash($_POST['order'])) : '';
		$taxonomy            = isset($_POST['taxonomy']) ? sanitize_text_field(wp_unslash($_POST['taxonomy'])) : '';
		$term_id             = isset($_POST['term_id']) ? sanitize_text_field(wp_unslash($_POST['term_id'])) : '';
		$pope_lang            = isset($_POST['lang']) ? sanitize_text_field(wp_unslash($_POST['lang'])) : '';
		$paged               = isset($_POST['page']) ? sanitize_text_field(wp_unslash($_POST['page'])) : '';
		$selected_term_list  = isset($_POST['term_list']) ? wp_unslash($_POST['term_list']) : '';
		$custom_fields_array = isset($_POST['custom_fields_array']) ? wp_unslash($_POST['custom_fields_array']) : '';
		$view_options        = get_post_meta($views_id, 'ta_pope_view_options', true);
		$layout              = get_post_meta($views_id, 'ta_pope_layouts', true);
		$layout_preset       = $pope_settings['layout_preset'];
		$pagination_type     = isset($view_options['post_pagination_type']) ? $view_options['post_pagination_type'] : '';
		$pagination_type     = isset($view_options['post_pagination_type_mobile']) ? $view_options['post_pagination_type_mobile'] : '';
		$query_args          = POPE_QueryInside::get_filtered_content($view_options, $views_id, $layout_preset, $post_per_page, $pope_post_limit, $pope_settings);
		$tax_settings        = array();
		$post_offset         = isset($view_options['pope_post_offset']) ? $view_options['pope_post_offset'] : 0;

		$new_query_args                   = $query_args;
		$new_query_args['fields']         = 'ids';
		$post_limit                       = isset($view_options['pope_post_limit']) && !empty($view_options['pope_post_limit']) ? $view_options['pope_post_limit'] : 10000;
		$new_query_args['posts_per_page'] = $post_limit;
		$query_post_ids                   = get_posts($new_query_args);
		$query_post_ids                   = array('');

		$relation   = isset($pope_settings['taxonomies_relation']) ? $pope_settings['taxonomies_relation'] : 'AND';
		$query_args = POPE_Functions::modify_query_params($query_args, $keyword, $author_id, $custom_fields_array, $orderby, $order, $selected_term_list, $post_offset, $relation, $query_post_ids, $pope_lang);
		$pope_query  = new WP_Query($query_args);
		POPE_HTML::pope_pagination_bar($pope_query, $view_options, $layout_preset, $views_id, $pope_settings, $post_per_page, $pope_post_limit);
		die();
	}

	/**
	 * Post Ajax filter.
	 */
	public static function pope_post_order()
	{
		if (isset($_POST['nonce']) && !wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['nonce'])), 'sppope_nonce')) {
			return false;
		}
		$views_id               = isset($_POST['id']) ? absint($_POST['id']) : '';
		$pope_settings          = isset($_POST['pope_settings']) ? $_POST['pope_settings'] : '';
		$post_per_page          = isset($_POST['post_per_page']) ? $_POST['post_per_page'] : '';
		$pope_post_limit        = isset($_POST['pope_post_limit']) ? $_POST['pope_post_limit'] : '';
		$author_id              = isset($_POST['author_id']) ? sanitize_text_field(wp_unslash($_POST['author_id'])) : '';
		$keyword                = isset($_POST['keyword']) ? sanitize_text_field(wp_unslash($_POST['keyword'])) : '';
		$orderby                = isset($_POST['orderby']) ? sanitize_text_field(wp_unslash($_POST['orderby'])) : '';
		$order                  = isset($_POST['order']) ? sanitize_text_field(wp_unslash($_POST['order'])) : '';
		$taxonomy               = isset($_POST['taxonomy']) ? sanitize_text_field(wp_unslash($_POST['taxonomy'])) : '';
		$term_id                = isset($_POST['term_id']) ? sanitize_text_field(wp_unslash($_POST['term_id'])) : '';
		$pope_lang              = isset($_POST['lang']) ? sanitize_text_field(wp_unslash($_POST['lang'])) : '';
		$selected_term_list     = isset($_POST['term_list']) ? wp_unslash($_POST['term_list']) : '';
		$custom_fields_array    = isset($_POST['custom_fields_array']) ? wp_unslash($_POST['custom_fields_array']) : '';
		$layout                 = get_post_meta($views_id, 'ta_pope_layouts', true);
		$layout_preset          = $pope_settings['layout_preset'];
		$view_options           = get_post_meta($views_id, 'ta_pope_view_options', true);
		$pagination_type        = isset($pope_settings['post_pagination_type']) ? $pope_settings['post_pagination_type'] : '';
		$pagination_type_mobile = isset($view_options['post_pagination_type_mobile']) ? $view_options['post_pagination_type_mobile'] : '';
		$post_content_sorter    = isset($view_options['post_content_sorter']) ? $view_options['post_content_sorter'] : '';
		$query_args             = POPE_QueryInside::get_filtered_content($view_options, $views_id, $layout_preset, $post_per_page, $pope_post_limit, $pope_settings);
		$post_offset            = isset($pope_settings['pope_post_offset']) ? $pope_settings['pope_post_offset'] : 0;

		$new_query_args                   = $query_args;
		$new_query_args['fields']         = 'ids';	
		$post_limit                       = isset($pope_post_limit) && !empty($pope_post_limit) ? $pope_post_limit : 10000;
		$new_query_args['posts_per_page'] = $post_limit;
		$query_post_ids                   = get_posts($new_query_args);
		$relation                         = isset($pope_settings['taxonomies_relation']) ? $pope_settings['taxonomies_relation'] : 'AND';
		$query_args                       = POPE_Functions::modify_query_params($query_args, $keyword, $author_id, $custom_fields_array, $orderby, $order, $selected_term_list, $post_offset, $relation, $query_post_ids, $pope_lang);
		$pope_query                        = new WP_Query($query_args);

		POPE_HTML::pope_get_posts($view_options, $layout_preset, $post_content_sorter, $pope_query, $views_id, $pope_settings);
		die();
	}

    /**
     * Init Widgets
     * @since 1.0.0
     */
    public function init_widgets()
    {
        require_once PPFE_PLUGIN_PATH . '/widgets/postify-post-grid.php';
        require_once PPFE_PLUGIN_PATH . '/widgets/postify-post-carousel.php';
    }

    /**
     * Init Category Section
     * @since 1.0.0
     */
    public function init_category()
    {
        Elementor\Plugin::instance()->elements_manager->add_category(
            'ppfe-for-elementor',
            [
                'title' => 'Postify Pro'
            ],
            1
        );
    }

    /**
     * Admin Notice
     * Warning when the site doesn't have Elementor installed or activated
     * @since 1.0.0
     */
    public function admin_notice_missing_main_plugin()
    {
        if (isset($_GET['activate'])) unset($_GET['activate']);
        $message = sprintf(
            esc_html__('"%1$s" requires "%2$s" to be installed and activated', 'postify-pro-for-elementor'),
            '<strong>' . esc_html__('Postify For Elementor', 'postify-pro-for-elementor') . '</strong>',
            '<strong>' . esc_html__('Elementor', 'postify-pro-for-elementor') . '</strong>'
        );

        printf('<div class="notice notice-warning is-dimissible"><p>%1$s</p></div>', $message);
    }

    /**
     * Admin Notice
     * Warning when the site doesn't have a minimum required Elementor version.
     * @since 1.0.0
     */
    public function admin_notice_minimum_elementor_version()
    {
        if (isset($_GET['activate'])) unset($_GET['activate']);
        $message = sprintf(
            esc_html__('"%1$s" requires "%2$s" version %3$s or greater', 'postify-pro-for-elementor'),
            '<strong>' . esc_html__('Postify For Elementor', 'postify-pro-for-elementor') . '</strong>',
            '<strong>' . esc_html__('Elementor', 'postify-pro-for-elementor') . '</strong>',
            self::MINIMUM_ELEMENTOR_VERSION
        );
        printf('<div class="notice notice-warning is-dimissible"><p>%1$s</p></div>', $message);
    }

    /**
     * Admin Notice
     * Warning when the site doesn't have a minimum required PHP version.
     * @since 1.0.0
     */
    public function admin_notice_minimum_php_version()
    {
        if (isset($_GET['activate'])) unset($_GET['activate']);
        $message = sprintf(
            esc_html__('"%1$s" requires "%2$s" version %3$s or greater', 'postify-pro-for-elementor'),
            '<strong>' . esc_html__('Postify For Elementor', 'postify-pro-for-elementor') . '</strong>',
            '<strong>' . esc_html__('PHP', 'postify-pro-for-elementor') . '</strong>',
            self::MINIMUM_PHP_VERSION
        );
        printf('<div class="notice notice-warning is-dimissible"><p>%1$s</p></div>', $message);
    }
}
Postify_Pro_For_Elementor::instance();
