<?php

class POPE_Layout
{
    /**
     * Content Layout Options.
     */
    public static function ppfe_content_layout_options($widget)
    {
        $widget->start_controls_section(
            'section_layout',
            [
                'label' => esc_html__('Layout', 'postify-pro-for-elementor'),
            ]
        );

        $widget->add_control(
            'content_orientation',
            [
                'label' => esc_html__('Content Orientation', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'default' => esc_html__('Default', 'postify-pro-for-elementor'),
                    'overlay' => esc_html__('Overlay', 'postify-pro-for-elementor'),
                ],
                'default' => 'default',
            ]
        );
        
        $widget->add_control(
            'pope_sticky_post',
            [
                'label' => esc_html__('Sticky Post', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options'    => array(
                    'normal_position' => esc_html__( 'Normal Position', 'postify-pro-for-elementor' ),
                    'top_list'        => esc_html__( 'Top of the List', 'postify-pro-for-elementor' ),
                    'hide'            => esc_html__( 'Hide Sticky Posts', 'postify-pro-for-elementor' ),
                ),
                'default' => 'normal_position',
            ]
        );

        $widget->add_control(
            'pope_include_only_posts',
            [
                'label'         => esc_html__('Include Only', 'postify-pro-for-elementor'),
                'type'          => \Elementor\Controls_Manager::SELECT2,
                'label_block'   => true,
                'multiple'      => true,
                'options'       => POPE_Utilities_Functions::include_only_post(),
                'conditions' => [
                    'terms' => [
                        [
                            'name' => 'pope_exclude_post_set',
                            'operator' => '!=',
                            'value' => true,
                        ],
                    ],
                ],
            ]
        );

        $widget->add_control(
            'pope_exclude_post_set',
            [
                'label'         => esc_html__('Exclude', 'postify-pro-for-elementor'),
                'type'          => \Elementor\Controls_Manager::SELECT2,
                'label_block'   => true,
                'multiple'      => true,
                'options'       => POPE_Utilities_Functions::include_only_post(),
                'conditions' => [
                    'terms' => [
                        [
                            'name' => 'pope_include_only_posts',
                            'operator' => '!=',
                            'value' => true,
                        ],
                    ],
                ],
            ]
        );

        $widget->add_control(
            'pope_exclude_too',
            [
                'type'          => \Elementor\Controls_Manager::SELECT2,
                'label_block'   => true,
                'multiple'      => true,
                'options'       => array(
                    'current'               => esc_html__( 'Current Post', 'postify-pro-for-elementor' ),
                    'password_protected'    => esc_html__( 'Password Protected Posts', 'postify-pro-for-elementor' ),
                    'children'              => esc_html__( 'Children Posts', 'postify-pro-for-elementor' ),
                ),
            ]
        );

        $widget->add_control(
            'pope_post_limit',
            [
                'label'         => esc_html__('Limit', 'postify-pro-for-elementor'),
                'description'   => esc_html__('Number of total items to display.', 'postify-pro-for-elementor'),
                'type'          => \Elementor\Controls_Manager::NUMBER,
                'default'       => 20,
            ]
        );
        $widget->add_control(
            'pope_post_offset',
            [
                'label'         => esc_html__('Offset', 'postify-pro-for-elementor'),
                'description'   => esc_html__('Number of total items to display.', 'postify-pro-for-elementor'),
                'type'          => \Elementor\Controls_Manager::NUMBER,
                'default'       => 0,
            ]
        );

        $widget->add_control(
            'item_same_height',
            [
                'label'         => esc_html__('Same Height', 'postify-pro-for-elementor'),
                'type'          => \Elementor\Controls_Manager::SWITCHER,
                'label_on'      => esc_html__('Show', 'postify-pro-for-elementor'),
                'label_off'     => esc_html__('Hide', 'postify-pro-for-elementor'),
            ]
        );

        $widget->add_control(
            'show_image',
            [
                'label'         => esc_html__('Image', 'postify-pro-for-elementor'),
                'type'          => \Elementor\Controls_Manager::SWITCHER,
                'label_on'      => esc_html__('Show', 'postify-pro-for-elementor'),
                'label_off'     => esc_html__('Hide', 'postify-pro-for-elementor'),
                'default'       => 'yes',
                'separator'     => 'before',
            ]
        );

        $widget->add_group_control(
            \Elementor\Group_Control_Image_Size::get_type(),
            [
                'name'          => 'post_thumbnail',
                'default'       => 'full',
                'prefix_class'  => 'post-thumbnail-size-',
                'condition'     => [
                    'show_image' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'load_2x_image',
            [
                'label'         => esc_html__('Load 2x Resolution Image in Retina Display', 'postify-pro-for-elementor'),
                'type'          => \Elementor\Controls_Manager::SWITCHER,
                'label_on'      => esc_html__('Show', 'postify-pro-for-elementor'),
                'label_off'     => esc_html__('Hide', 'postify-pro-for-elementor'),
                'condition'     => [
                    'show_image' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'thumb_src_replace',
            [
                'label'         => esc_html__('Replace With', 'postify-pro-for-elementor'),
                'type'          => \Elementor\Controls_Manager::SELECT2,
                'multiple'      => true,
                'options'       => [
                    'image'     => esc_html__('Image', 'postify-pro-for-elementor'),
                    'video'     => esc_html__('Video', 'postify-pro-for-elementor'),
                    'audio'     => esc_html__('Audio', 'postify-pro-for-elementor'),
                ],
                'default'       => 'none',
                'condition'     => [
                    'show_image' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'thumb_zoom',
            [
                'label'         => esc_html__('Zoom Effect', 'postify-pro-for-elementor'),
                'type'          => \Elementor\Controls_Manager::SELECT,
                'options'       => [
                    'none'      => esc_html__('None', 'postify-pro-for-elementor'),
                    'zoom_in'   => esc_html__('Zoom In', 'postify-pro-for-elementor'),
                    'zoom_out'  => esc_html__('Zoom Out', 'postify-pro-for-elementor'),
                ],
                'default'       => 'none',
                'condition'     => [
                    'show_image' => 'yes',
                ],
                'selectors' => [
                    '{{WRAPPER}} .postify .zoom_out img' => 'transform: scale(1.08);',
                    '{{WRAPPER}} .postify .zoom_in:hover img' => 'transform: scale(1.08);',
                    '{{WRAPPER}} .postify .zoom_out:hover img' => 'transform: scale(1.0);',
                ],
            ]
        );

        $widget->add_control(
            'thumb_gray_scale',
            [
                'label'         => esc_html__('Image Mode', 'postify-pro-for-elementor'),
                'type'          => \Elementor\Controls_Manager::SELECT,
                'options'       => [
                    'none'      => esc_html__('Normal', 'postify-pro-for-elementor'),
                    'gray_and_normal'   => esc_html__('Grayscale and normal on hover', 'postify-pro-for-elementor'),
                    'gray_on_hover'     => esc_html__('Grayscale on hover', 'postify-pro-for-elementor'),
                    'always_gray'       => esc_html__('Always grayscale', 'postify-pro-for-elementor'),
                ],
                'default'       => 'none',
                'condition'     => [
                    'show_image' => 'yes',
                ],
                'selectors' => [
                    '{{WRAPPER}} .postify__item.gray_and_normal img' => '-webkit-filter: grayscale(100%);filter: grayscale(100%);',
                    '{{WRAPPER}} .postify__item.gray_and_normal:hover img' => '-webkit-filter: grayscale(0);filter: grayscale(0);',
                    '{{WRAPPER}} .postify__item.gray_on_hover img' => '-webkit-filter: grayscale(0);filter: grayscale(0);',
                    '{{WRAPPER}} .postify__item.gray_on_hover:hover img' => '-webkit-filter: grayscale(100%);filter: grayscale(100%);',
                    '{{WRAPPER}} .postify__item.always_gray img' => '-webkit-filter: grayscale(100%);filter: grayscale(100%);',
                ],
            ]
        );

        $widget->add_control(
            'thumb_lazy_load',
            [
                'label'         => esc_html__('Lazy Load', 'postify-pro-for-elementor'),
                'type'          => \Elementor\Controls_Manager::SWITCHER,
                'label_on'      => esc_html__('Show', 'postify-pro-for-elementor'),
                'label_off'     => esc_html__('Hide', 'postify-pro-for-elementor'),
                'default'       => 'yes',
            ]
        );

        $widget->add_control(
            'thumb_meta',
            [
                'label'         => esc_html__('Show Thumb Meta', 'postify-pro-for-elementor'),
                'type'          => \Elementor\Controls_Manager::SELECT,
                'options'       => [
                    'category'  => esc_html__('Category', 'postify-pro-for-elementor'),
                    'date'      => esc_html__('Date', 'postify-pro-for-elementor'),
                    'none'      => esc_html__('None', 'postify-pro-for-elementor'),
                ],
                'default'       => 'none',
                'condition'     => [
                    'show_image' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'thumb_meta_taxonomy',
            [
                'label'         => esc_html__('Select Taxonomy', 'postify-pro-for-elementor'),
                'type'          => \Elementor\Controls_Manager::SELECT,
                'options'       => array_merge(['' => esc_html__('Select Taxonomy', 'postify-pro-for-elementor')], POPE_Utilities_Functions::get_post_type_taxonomies('post')),
                'condition'     => [
                    'show_image' => 'yes',
                    'thumb_meta' => 'category',
                ],
            ]
        );

        $widget->add_control(
            'thumb_meta_date_format',
            [
                'label'         => esc_html__('Date Format', 'postify-pro-for-elementor'),
                'type'          => \Elementor\Controls_Manager::SELECT,
                'options'       => [
                    'default'   => esc_html__('Default', 'postify-pro-for-elementor'),
                    'time_ago'  => esc_html__('Time ago(human time)', 'postify-pro-for-elementor'),
                    'custom'    => esc_html__('Custom', 'postify-pro-for-elementor'),
                ],
                'default'       => 'default',
                'condition'     => [
                    'show_image' => 'yes',
                    'thumb_meta' => 'date',
                ],
            ]
        );

        $widget->add_control(
            'custom_date_format',
            [
                'label'         => esc_html__('Custom Format ', 'postify-pro-for-elementor'),
                'type'          => \Elementor\Controls_Manager::TEXT,
                'placeholder'   => esc_html__('F j, Y', 'postify-pro-for-elementor'),
                'description'   => esc_html__('To define format, check <a href="https://wordpress.org/support/article/formatting-date-and-time/" target="_blank" rel="noopener noreferrer nofollow"><em>this doc</em></a>.', 'postify-pro-for-elementor'),
                'condition'     => [
                    'show_image' => 'yes',
                    'thumb_meta' => 'date',
                    'thumb_meta_date_format' => 'custom',
                ],
            ]
        );

        $widget->add_control(
            'thumb_meta_position',
            [
                'label' => esc_html__('Taxonomy Position', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'top_right'         => esc_html__('Top right', 'postify-pro-for-elementor'),
                    'top_center'        => esc_html__('Top center', 'postify-pro-for-elementor'),
                    'top_left'          => esc_html__('Top left', 'postify-pro-for-elementor'),
                    'bottom_left'       => esc_html__('Bottom left', 'postify-pro-for-elementor'),
                    'bottom_center'     => esc_html__('Bottom center', 'postify-pro-for-elementor'),
                    'bottom_right'      => esc_html__('Bottom right', 'postify-pro-for-elementor'),
                ],
                'default'   => 'top_right',
                'condition' => [
                    'show_image' => 'yes',
                    'thumb_meta!' => 'none',
                ],
            ]
        );

        $widget->add_control(
            'show_title',
            [
                'label'         => esc_html__('Title', 'postify-pro-for-elementor'),
                'type'          => \Elementor\Controls_Manager::SWITCHER,
                'label_on'      => esc_html__('Show', 'postify-pro-for-elementor'),
                'label_off'     => esc_html__('Hide', 'postify-pro-for-elementor'),
                'default'       => 'yes',
                'separator'     => 'before',
            ]
        );

        $widget->add_control(
            'title_tag',
            [
                'label' => esc_html__('Title HTML Tag', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'h1' => 'H1',
                    'h2' => 'H2',
                    'h3' => 'H3',
                    'h4' => 'H4',
                    'h5' => 'H5',
                    'h6' => 'H6',
                    'div' => 'div',
                    'span' => 'span',
                    'p' => 'p',
                ],
                'default' => 'h3',
                'condition' => [
                    'show_title' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'title_limit',
            [
                'label' => esc_html__('Limit Character', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'postify-pro-for-elementor'),
                'label_off' => esc_html__('Hide', 'postify-pro-for-elementor'),
            ]
        );
        $widget->add_control(
            'title_length',
            [
                'label' => esc_html__('Length', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => '30',
                'condition' => [
                    'title_limit' => 'yes',
                ],
            ]
        );
        $widget->add_control(
            'title_alignment',
            [
                'label' => esc_html__('Alignment', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__('Left', 'postify-pro-for-elementor'),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__('Center', 'postify-pro-for-elementor'),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__('Right', 'postify-pro-for-elementor'),
                        'icon' => 'eicon-text-align-right',
                    ],
                ],
                'default' => 'left',
                'selectors' => [
                    '{{WRAPPER}} .postify__item .postify__item--title' => 'text-align: {{VALUE}};',
                ],
                'condition' => [
                    'show_title' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'show_content',
            [
                'label' => esc_html__('Content', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'postify-pro-for-elementor'),
                'label_off' => esc_html__('Hide', 'postify-pro-for-elementor'),
                'default' => 'yes',
                'separator' => 'before',
            ]
        );

        $widget->add_control(
            'content_type',
            [
                'label' => esc_html__('Content Display Type', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'excerpt'  => esc_html__('Excerpt', 'postify-pro-for-elementor'),
                    'limit_content' => esc_html__('Content with Limit', 'postify-pro-for-elementor'),
                    'full_content' => esc_html__('Full Content', 'postify-pro-for-elementor'),
                ],
                'default' => 'limit_content',
                'condition' => [
                    'show_content' => 'yes',
                ],
            ]
        );
        $widget->add_control(
            'content_length_type',
            [
                'label' => esc_html__('Content Length Type', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'words'  => esc_html__('Words', 'postify-pro-for-elementor'),
                    'characters' => esc_html__('Characters', 'postify-pro-for-elementor'),
                ],
                'default' => 'words',
                'condition' => [
                    'show_content' => 'yes',
                    'content_type' => 'limit_content',
                ],
            ]
        );
        $widget->add_control(
            'content_limit',
            [
                'label'     => esc_html__('Words Length', 'postify-pro-for-elementor'),
                'type'      => \Elementor\Controls_Manager::NUMBER,
                'default'   => '30',
                'max'       => '1000',
                'condition' => [
                    'show_content' => 'yes',
                    'content_type' => 'limit_content',
                    'content_length_type' => 'words',
                ],
            ]
        );

        $widget->add_control(
            'content_characters_limit',
            [
                'label' => esc_html__('Characters Length', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => '30',
                'max' => '1000',
                'condition' => [
                    'show_content' => 'yes',
                    'content_type' => 'limit_content',
                    'content_length_type' => 'characters',
                ],
            ]
        );

        $widget->add_control(
            'strip_tags',
            [
                'label' => esc_html__('HTML Tags', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'limit_content',
                'options' => [
                    'allow_all'  => esc_html__('Allow All', 'postify-pro-for-elementor'),
                    'strip_all' => esc_html__('Strip All', 'postify-pro-for-elementor'),
                    'allow_some' => esc_html__('Allow Some', 'postify-pro-for-elementor'),
                ],
                'default' => 'allow_all',
                'condition' => [
                    'show_content' => 'yes',
                    'content_type!' => 'excerpt',
                ],
            ]
        );
        $widget->add_control(
            'allow_tag_name',
            [
                'label'     => esc_html__('HTML Tags Names', 'postify-pro-for-elementor'),
                'type'      => \Elementor\Controls_Manager::TEXT,
                'condition' => [
                    'show_content' => 'yes',
                    'strip_tags' => 'allow_some',
                ],
            ]
        );
        $widget->add_control(
            'content_ellipsis',
            [
                'label'     => esc_html__('Ending Excerpt', 'postify-pro-for-elementor'),
                'type'      => \Elementor\Controls_Manager::TEXT,
                'default'   => '...',
                'condition' => [
                    'show_content' => 'yes',
                    'content_type!' => 'full_content',
                ],
            ]
        );
        $widget->add_control(
            'content_alignment',
            [
                'label' => esc_html__('Alignment', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__('Left', 'postify-pro-for-elementor'),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__('Center', 'postify-pro-for-elementor'),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__('Right', 'postify-pro-for-elementor'),
                        'icon' => 'eicon-text-align-right',
                    ],
                ],
                'default' => 'left',
                'selectors' => [
                    '{{WRAPPER}} .postify__item .postify__item__content' => 'text-align: {{VALUE}};',
                ],
                'condition' => [
                    'show_content' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'show_read_more',
            [
                'label' => esc_html__('Read More', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'postify-pro-for-elementor'),
                'label_off' => esc_html__('Hide', 'postify-pro-for-elementor'),
                'default' => 'yes',
            ]
        );

        $widget->add_control(
            'read_more_type',
            [
                'label' => esc_html__('Read More Type', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'limit_content',
                'options' => [
                    'button'  => esc_html__('Button', 'postify-pro-for-elementor'),
                    'text_link' => esc_html__('Text Link', 'postify-pro-for-elementor'),
                ],
                'default' => 'button',
                'condition' => [
                    'show_read_more' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'read_more_text',
            [
                'label' => esc_html__('Read More Text', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__('Read More', 'postify-pro-for-elementor'),
                'condition' => [
                    'show_read_more' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'show_meta',
            [
                'label' => esc_html__('Meta Fields', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'postify-pro-for-elementor'),
                'label_off' => esc_html__('Hide', 'postify-pro-for-elementor'),
                'default' => 'yes',
                'separator' => 'before',
            ]
        );

        $widget->add_control(
            'meta_data',
            [
                'label' => esc_html__('Meta Data', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::SELECT2,
                'multiple' => true,
                'label_block' => true,
                'options' => [
                    'author' => esc_html__('Author', 'postify-pro-for-elementor'),
                    'date' => esc_html__('Date', 'postify-pro-for-elementor'),
                    'categories' => esc_html__('Categories', 'postify-pro-for-elementor'),
                    'comments' => esc_html__('Comments', 'postify-pro-for-elementor'),
                    'like' => esc_html__('Like', 'postify-pro-for-elementor'),
                    'reading_time' => esc_html__('Reading Time', 'postify-pro-for-elementor'),
                ],
                'default' => ['author', 'date', 'comments'],
                'condition' => [
                    'show_meta' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'author_toggle',
            [
                'label' => esc_html__('Author', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::POPOVER_TOGGLE,
                'condition' => [
                    'show_meta' => 'yes',
                    'meta_data' => 'author',
                ],
            ]
        );

        $widget->start_popover();
        $widget->add_control(
            'meta_author_avatar',
            [
                'label' => esc_html__('Avatar', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'show_name' => esc_html__('Show name', 'postify-pro-for-elementor'),
                    'show_gravatar' => esc_html__('Show gravatar', 'postify-pro-for-elementor'),
                    'name_with_gravatar' => esc_html__('Author name & gravatar', 'postify-pro-for-elementor'),
                    'name_with_icon' => esc_html__('Author name with an icon', 'postify-pro-for-elementor'),
                ],
                'default' => 'name_with_icon',
            ]
        );
        $widget->add_control(
            'author_icon',
            [
                'label' => esc_html__('Author Icon', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'far fa-user',
                    'library' => 'fa-solid',
                ],
                'recommended' => [
                    'fa-solid' => [
                        'user',
                        'user-alt',
                        'user-circle',
                    ],
                    'fa-regular' => [
                        'user',
                        'user-alt',
                        'user-circle',
                    ],
                ],
            ]
        );
        $widget->end_popover();

        $widget->add_control(
            'date_toggle',
            [
                'label' => esc_html__('Date', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::POPOVER_TOGGLE,
                'condition' => [
                    'show_meta' => 'yes',
                    'meta_data' => 'date',
                ],
            ]
        );

        $widget->start_popover();
        $widget->add_control(
            'meta_date_format',
            [
                'label' => esc_html__('Date Format', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'default' => esc_html__('Default', 'postify-pro-for-elementor'),
                    'time_ago' => esc_html__('Time ago(human time)', 'postify-pro-for-elementor'),
                    'custom' => esc_html__('Custom', 'postify-pro-for-elementor'),
                ],
                'default' => 'default',
            ]
        );
        $widget->add_control(
            'meta_custom_date_format',
            [
                'label' => esc_html__('Custom Format ', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'placeholder'   => esc_html__('F j, Y', 'postify-pro-for-elementor'),
                'description' => esc_html__('To define format, check <a href="https://wordpress.org/support/article/formatting-date-and-time/" target="_blank" rel="noopener noreferrer nofollow"><em>this doc</em></a>.', 'postify-pro-for-elementor'),
                'condition'     => [
                    'meta_date_format' => 'custom',
                ],
            ]
        );
        $widget->add_control(
            'date_icon',
            [
                'label' => esc_html__('Date Icon', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'far fa-clock',
                    'library' => 'fa-regular',
                ],
                'recommended' => [
                    'fa-solid' => [
                        'clock',
                    ],
                    'fa-regular' => [
                        'clock',
                    ],
                ],
            ]
        );
        $widget->end_popover();

        $widget->add_control(
            'taxonomy',
            [
                'label' => esc_html__('Taxonomy', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::POPOVER_TOGGLE,
                'condition' => [
                    'show_meta' => 'yes',
                    'meta_data' => 'categories',
                ],
            ]
        );

        $widget->start_popover();
        $widget->add_control(
            'meta_categories',
            [
                'label'         => esc_html__('Select Taxonomy', 'postify-pro-for-elementor'),
                'type'          => \Elementor\Controls_Manager::SELECT,
                'options'       => array_merge(['' => esc_html__('Select Taxonomy', 'postify-pro-for-elementor')], POPE_Utilities_Functions::get_post_type_taxonomies('post')),
            ]
        );

        $widget->add_control(
            'categories_icon',
            [
                'label' => esc_html__('Taxonomy Icon', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'fas fa-tag',
                    'library' => 'fa-solid',
                ],
                'recommended' => [
                    'fa-solid' => [
                        'tag',
                        'tags',
                    ],
                ],
            ]
        );
        $widget->end_popover();

        $widget->add_control(
            'comments_toggle',
            [
                'label' => esc_html__('Comments', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::POPOVER_TOGGLE,
                'condition' => [
                    'show_meta' => 'yes',
                    'meta_data' => 'comments',
                ],
            ]
        );

        $widget->start_popover();

        $widget->add_control(
            'comments_icon',
            [
                'label' => esc_html__('Comments Icon', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'fas fa-comment-alt',
                    'library' => 'fa-solid',
                ],
                'recommended' => [
                    'fa-solid' => [
                        'comment',
                        'comment-alt',
                        'comments',
                    ],
                    'fa-regular' => [
                        'comment',
                        'comment-alt',
                        'comments',
                    ],
                ],
            ]
        );
        $widget->end_popover();

        $widget->add_control(
            'reading_time_toggle',
            [
                'label' => esc_html__('Reading Time', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::POPOVER_TOGGLE,
                'condition' => [
                    'show_meta' => 'yes',
                    'meta_data' => 'reading_time',
                ],
            ]
        );

        $widget->start_popover();

        $widget->add_control(
            'word_per_minute',
            [
                'label' => esc_html__('Word Per Minute', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::NUMBER,
                /** This filter is documented in wp-includes/formatting.php */
                'default' => apply_filters('excerpt_length', 25),
            ]
        );

        $widget->add_control(
            'reading_time_icon',
            [
                'label' => esc_html__('Reading Time Icon', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'fas fa-book-reader',
                    'library' => 'fa-solid',
                ],
                'recommended' => [
                    'fa-solid' => [
                        'book-reader',
                    ],
                ],
            ]
        );

        $widget->add_control(
            'reading_time_postfix',
            [
                'label' => esc_html__('Reading Time Postfix', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__(' Min Read', 'postify-pro-for-elementor'),
            ]
        );
        $widget->end_popover();

        $widget->add_control(
            'meta_separator',
            [
                'label' => esc_html__('Separator Between', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'selectors' => [
                    '{{WRAPPER}} .ppfe-grid-container .postify__item .postify__item__content--meta span + span:before' => 'content: "{{VALUE}}"',
                ],
                'condition' => [
                    'show_meta' => 'yes',
                    'meta_data!' => [],
                ],
            ]
        );

        $widget->add_control(
            'meta_alignment',
            [
                'label' => esc_html__('Alignment', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__('Left', 'postify-pro-for-elementor'),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__('Center', 'postify-pro-for-elementor'),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__('Right', 'postify-pro-for-elementor'),
                        'icon' => 'eicon-text-align-right',
                    ],
                ],
                'default' => 'left',
                'selectors' => [
                    '{{WRAPPER}} .postify__item .postify__item--meta ul' => 'justify-content: {{VALUE}};',
                ],
                'condition' => [
                    'show_social_share' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'show_social_share',
            [
                'label' => esc_html__('Social Share', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'postify-pro-for-elementor'),
                'label_off' => esc_html__('Hide', 'postify-pro-for-elementor'),
                'default' => 'yes',
                'separator' => 'before',
            ]
        );

        $widget->add_control(
            'social_sharing_media',
            [
                'label' => esc_html__('Sharing Media', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::SELECT2,
                'multiple' => true,
                'label_block' => true,
                'options' => [
                    'facebook' => esc_html__('Facebook', 'postify-pro-for-elementor'),
                    'twitter' => esc_html__('Twitter', 'postify-pro-for-elementor'),
                    'linkedIn' => esc_html__('LinkedIn', 'postify-pro-for-elementor'),
                    'pinterest' => esc_html__('Pinterest', 'postify-pro-for-elementor'),
                    'email' => esc_html__('Email', 'postify-pro-for-elementor'),
                    'instagram' => esc_html__('Instagram', 'postify-pro-for-elementor'),
                    'vk'   => esc_html__('VK', 'postify-pro-for-elementor'),
                    'digg' => esc_html__('digg', 'postify-pro-for-elementor'),
                    'tumblr' => esc_html__('Tumblr', 'postify-pro-for-elementor'),
                    'reddit' => esc_html__('Reddit', 'postify-pro-for-elementor'),
                    'whatsapp' => esc_html__('WhatsApp', 'postify-pro-for-elementor'),
                    'pocket' => esc_html__('Pocket', 'postify-pro-for-elementor'),
                    'xing' => esc_html__('Xing', 'postify-pro-for-elementor'),
                ],
                'condition' => [
                    'show_social_share' => 'yes',
                ],
            ]
        );
        $widget->add_control(
            'social_media_alignment',
            [
                'label' => esc_html__('Alignment', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__('Left', 'postify-pro-for-elementor'),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__('Center', 'postify-pro-for-elementor'),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__('Right', 'postify-pro-for-elementor'),
                        'icon' => 'eicon-text-align-right',
                    ],
                ],
                'default' => 'left',
                'selectors' => [
                    '{{WRAPPER}} .postify__item__socail-share' => 'text-align: {{VALUE}};',
                ],
                'condition' => [
                    'show_social_share' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'show_preloader',
            [
                'label' => esc_html__('Preloader', 'postify-pro-for-elementor'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'postify-pro-for-elementor'),
                'label_off' => esc_html__('Hide', 'postify-pro-for-elementor'),
            ]
        );

        $widget->end_controls_section();
    }
}
