<?php

use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;

class POPE_Query_Style_Readmore
{
    public static function ppfe_style_readmore_options($widget)
    {
        $widget->start_controls_section(
            'section_grid_readmore_style',
            [
                'label' => esc_html__('Read More', 'postify-pro-for-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [
                    'show_read_more' => 'yes',
                ],
            ]
        );

        // Readmore typography.
        $widget->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name'      => 'grid_readmore_style_typography',
                'global' => [
                    'default' => Global_Typography::TYPOGRAPHY_ACCENT,
                ],
                'selector'  => '{{WRAPPER}} .postify .postify__item .postify__item__content__readmore a',
            ]
        );

        $widget->start_controls_tabs('grid_readmore_color_style');

        // Normal tab.
        $widget->start_controls_tab(
            'grid_readmore_style_normal',
            array(
                'label' => esc_html__('Normal', 'postify-pro-for-elementor'),
            )
        );

        // Readmore color.
        $widget->add_control(
            'grid_readmore_style_color',
            [
                'type'      => \Elementor\Controls_Manager::COLOR,
                'label'     => esc_html__('Color', 'postify-pro-for-elementor'),
                'global' => [
                    'default' => Global_Colors::COLOR_TEXT,
                ],
                'selectors' => [
                    '{{WRAPPER}} .postify .postify__item .postify__item__content__readmore a' => 'color: {{VALUE}};',
                ],
            ]
        );

        // Readmore background color.
        $widget->add_control(
            'grid_readmore_style_background_color',
            [
                'type'      => \Elementor\Controls_Manager::COLOR,
                'label'     => esc_html__('Background Color', 'postify-pro-for-elementor'),
                'selectors' => [
                    '{{WRAPPER}} .postify .postify__item .postify__item__content__readmore a' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        // Readmore border color.
        $widget->add_control(
            'grid_readmore_style_border_color',
            [
                'type'      => \Elementor\Controls_Manager::COLOR,
                'label'     => esc_html__('Border Color', 'postify-pro-for-elementor'),
                'selectors' => [
                    '{{WRAPPER}} .postify .postify__item .postify__item__content__readmore a' => 'border-color: {{VALUE}};',
                ],
            ]
        );

        $widget->end_controls_tab();

        // Hover tab.
        $widget->start_controls_tab(
            'grid_readmore_style_color_hover_tab',
            array(
                'label' => esc_html__('Hover', 'postify-pro-for-elementor'),
            )
        );

        // Readmore hover color.
        $widget->add_control(
            'grid_readmore_style_hover_color',
            array(
                'type'      => \Elementor\Controls_Manager::COLOR,
                'label'     => esc_html__('Color', 'postify-pro-for-elementor'),
                'global' => [
                    'default' => Global_Colors::COLOR_PRIMARY,
                ],
                'selectors' => array(
                    '{{WRAPPER}} .postify .postify__item .postify__item__content__readmore a:hover' => 'color: {{VALUE}};',
                ),
            )
        );

        // Readmore hover background color.
        $widget->add_control(
            'grid_readmore_style_hover_background_color',
            [
                'type'      => \Elementor\Controls_Manager::COLOR,
                'label'     => esc_html__('Background Color', 'postify-pro-for-elementor'),
                'selectors' => [
                    '{{WRAPPER}} .postify .postify__item .postify__item__content__readmore a:hover' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        // Readmore hover border color.
        $widget->add_control(
            'grid_readmore_style_hover_border_color',
            [
                'type'      => \Elementor\Controls_Manager::COLOR,
                'label'     => esc_html__('Border Color', 'postify-pro-for-elementor'),
                'selectors' => [
                    '{{WRAPPER}} .postify .postify__item .postify__item__content__readmore a:hover' => 'border-color: {{VALUE}};',
                ],
            ]
        );

        $widget->end_controls_tab();

        $widget->end_controls_tabs();

        // Readmore border width.
        $widget->add_control(
            'grid_readmore_style_border_width',
            [
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'label'      => esc_html__('Border Width', 'postify-pro-for-elementor'),
                'separator'  => 'before',
                'size_units' => array('px'),
                'selectors'  => [
                    '{{WRAPPER}} .postify .postify__item .postify__item__content__readmore a' => 'border-style: solid; border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
                ],
            ]
        );

        // Readmore border radius.
        $widget->add_control(
            'grid_readmore_style_border_radius',
            array(
                'label'     => esc_html__('Border Radius', 'postify-pro-for-elementor'),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'default'   => array(
                    'size' => 0,
                ),
                'range'     => array(
                    'px' => array(
                        'min' => 0,
                        'max' => 100,
                    ),
                ),
                'selectors' => array(
                    '{{WRAPPER}} .postify .postify__item .postify__item__content__readmore a' => 'border-radius: {{SIZE}}{{UNIT}}',
                ),
            )
        );

        // Readmore button padding.
        $widget->add_responsive_control(
            'grid_readmore_style_button_padding',
            array(
                'label'      => esc_html__('Padding', 'postify-pro-for-elementor'),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => array('px'),
                'selectors'  => array(
                    '{{WRAPPER}} .postify .postify__item .postify__item__content__readmore a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
                ),
            )
        );

        // Readmore margin.
        $widget->add_responsive_control(
            'grid_readmore_style_margin',
            [
                'label'      => esc_html__('Margin', 'postify-pro-for-elementor'),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px'],
                'default' => [
					'top' => 0,
					'right' => 0,
					'bottom' => 10,
					'left' => 0,
					'unit' => 'px',
					'isLinked' => false,
				],
                'selectors'  => [
                    '{{WRAPPER}} .postify .postify__item .postify__item__content__readmore a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $widget->end_controls_section();
    }
}
