<?php

use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;

class POPE_Query_Style_Social_Share
{
    public static function ppfe_style_social_share($widget)
    {
        $widget->start_controls_section(
            'section_grid_social_share',
            [
                'label' => esc_html__('Social Share', 'postify-pro-for-elementor'),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [
                    'show_social_share' => 'yes',
                ],
            ]
        );

        $widget->start_controls_tabs('grid_social_share_color_style');

        // Normal tab.
        $widget->start_controls_tab(
            'grid_social_share_normal',
            array(
                'label' => esc_html__('Normal', 'postify-pro-for-elementor'),
            )
        );

        // Social share color.
        $widget->add_control(
            'grid_social_share_color',
            [
                'type'      => \Elementor\Controls_Manager::COLOR,
                'label'     => esc_html__('Color', 'postify-pro-for-elementor'),
                'global' => [
                    'default' => Global_Colors::COLOR_TEXT,
                ],
                'selectors' => [
                    '{{WRAPPER}} .postify .postify__item .postify__item__socail-share a' => 'color: {{VALUE}};',
                ],
            ]
        );

        // Social share background color.
        $widget->add_control(
            'grid_social_share_background_color',
            [
                'type'      => \Elementor\Controls_Manager::COLOR,
                'label'     => esc_html__('Background Color', 'postify-pro-for-elementor'),
                'selectors' => [
                    '{{WRAPPER}} .postify .postify__item .postify__item__socail-share i' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        // Social share border color.
        $widget->add_control(
            'grid_social_share_border_color',
            [
                'type'      => \Elementor\Controls_Manager::COLOR,
                'label'     => esc_html__('Border Color', 'postify-pro-for-elementor'),
                'selectors' => [
                    '{{WRAPPER}} .postify .postify__item .postify__item__socail-share i' => 'border-color: {{VALUE}};',
                ],
            ]
        );

        $widget->end_controls_tab();

        // Hover tab.
        $widget->start_controls_tab(
            'grid_social_share_color_hover_tab',
            array(
                'label' => esc_html__('Hover', 'postify-pro-for-elementor'),
            )
        );

        // Social share hover color.
        $widget->add_control(
            'grid_social_share_hover_color',
            array(
                'type'      => \Elementor\Controls_Manager::COLOR,
                'label'     => esc_html__('Color', 'postify-pro-for-elementor'),
                'global' => [
                    'default' => Global_Colors::COLOR_PRIMARY,
                ],
                'selectors' => array(
                    '{{WRAPPER}} .postify .postify__item .postify__item__socail-share a:hover' => 'color: {{VALUE}};',
                ),
            )
        );

        // Social share hover background color.
        $widget->add_control(
            'grid_social_share_hover_background_color',
            [
                'type'      => \Elementor\Controls_Manager::COLOR,
                'label'     => esc_html__('Background Color', 'postify-pro-for-elementor'),
                'selectors' => [
                    '{{WRAPPER}} .postify .postify__item .postify__item__socail-share i:hover' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        // Social share hover border color.
        $widget->add_control(
            'grid_social_share_hover_border_color',
            [
                'type'      => \Elementor\Controls_Manager::COLOR,
                'label'     => esc_html__('Border Color', 'postify-pro-for-elementor'),
                'selectors' => [
                    '{{WRAPPER}} .postify .postify__item .postify__item__socail-share i:hover' => 'border-color: {{VALUE}};',
                ],
            ]
        );

        $widget->end_controls_tab();

        $widget->end_controls_tabs();

        // Social share border width.
        $widget->add_control(
            'grid_social_share_border_width',
            [
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'label'      => esc_html__('Border Width', 'postify-pro-for-elementor'),
                'separator'  => 'before',
                'size_units' => array('px'),
                'selectors'  => [
                    '{{WRAPPER}} .postify .postify__item .postify__item__socail-share i' => 'border-style: solid; border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
                ],
            ]
        );

        // Social share border radius.
        $widget->add_control(
            'grid_social_share_border_radius',
            array(
                'label'     => esc_html__('Border Radius', 'postify-pro-for-elementor'),
                'type'      => \Elementor\Controls_Manager::SLIDER,
                'default'   => array(
                    'size' => 0,
                ),
                'range'     => array(
                    'px' => array(
                        'min' => 0,
                        'max' => 100,
                    ),
                ),
                'selectors' => array(
                    '{{WRAPPER}} .postify .postify__item .postify__item__socail-share i' => 'border-radius: {{SIZE}}{{UNIT}}',
                ),
            )
        );

        // Social share margin.
        $widget->add_responsive_control(
            'grid_social_share_margin',
            [
                'label'      => esc_html__('Margin', 'postify-pro-for-elementor'),
                'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px'],
                'default' => [
					'top' => 0,
					'right' => 0,
					'bottom' => 10,
					'left' => 0,
					'unit' => 'px',
					'isLinked' => false,
				],
                'selectors'  => [
                    '{{WRAPPER}} .postify .postify__item .postify__item__socail-share' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $widget->end_controls_section();
    }
}
